Ext.data.JsonP.drawing_and_charting({"title":"Using Chart","guide":"<h1>Using The Draw and Chart Packages in Sencha Touch 2.1</h1>\n<div class='toc'>\n<p><strong>Contents</strong></p>\n<ol>\n<li><a href='#!/guide/drawing_and_charting-section-1'>Draw Component</a></li>\n<li><a href='#!/guide/drawing_and_charting-section-2'>Chart Component Overview</a></li>\n<li><a href='#!/guide/drawing_and_charting-section-3'>Axes</a></li>\n<li><a href='#!/guide/drawing_and_charting-section-4'>Series</a></li>\n<li><a href='#!/guide/drawing_and_charting-section-5'>Interactions</a></li>\n<li><a href='#!/guide/drawing_and_charting-section-6'>Legend</a></li>\n</ol>\n</div>\n\n<p>This guide provides an overview of the usage of the Sencha Touch 2.1 draw and chart packages. These packages\nenable you to create cross-browser and cross-device graphics in a versatile way.</p>\n\n<p>During the last several months the draw and chart packages have been through a refactor and now they are\ndirectly integrated into Sencha Touch 2.1. This refactor mainly focuses on:</p>\n\n<ol>\n<li><strong>Performance</strong> - This version of the draw and chart packages provides a significant performance enhancement.</li>\n<li><strong>Maintainability</strong> - The draw and chart functionality have been separated thoroughly. It will be easier to fix bugs and provide new\nfeatures.</li>\n<li><strong>Flexibility</strong> - Both the series and the sprites are provided in such a way that they are easier to customize and or\nextend. You can write your own sprite classes and define attributes that can be automatically animated and manipulated.</li>\n</ol>\n\n\n<p>The following topics are covered in this guide:</p>\n\n<ul>\n<li><strong>Draw Component</strong>: A cross-browser/cross-device package for drawing general purpose graphics and animations.</li>\n<li><strong>Chart Component</strong>: A hierarchy of classes that define a chart container, which provides the capability to visualize data.</li>\n</ul>\n\n\n<h2 id='drawing_and_charting-section-1'>Draw Component</h2>\n\n<p>The draw package is designed to meet development needs for mobile application graphics rendering, providing a\nversatile tool that capable of creating cross-browser, cross-device custom graphics and rich animations. The draw\npackage is designed for performance and enables rich user interactions through a large number of charts with a\nlow memory footprint.</p>\n\n<p>The draw package contains a Surface class (<code>Ext.draw.Surface</code>) that abstracts the underlying graphics implementation and enables the creation of arbitrarily shaped objects, called sprites, or groups of sprites. Sprites respond to interactions such as touch events (tap, swipe, and so on), and also provide rich animations on all style attributes, such as shape, color, size, and so on.</p>\n\n<p>The underlying implementation for the Surface class is the HTML Canvas engine. Canvas was chosen because procedural drawing with the 2D Canvas API usually outperforms DOM-based approaches.</p>\n\n<h3>Surface</h3>\n\n<p>You can create a simple drawing surface without loading the chart package at all. This can be useful for creating arbitrary graphics that work on all devices and that animate well. For example, you could create an interactive map of the United States in which each state is a sprite instead of a simple image, or an infographic whose elements are sprite. Using sprites instead of images gives web pages a richer user experience that includes interactivity and animation.</p>\n\n<pre class='inline-example preview'><code>var geo_data = [\n    \"M 772.07835,458.61245 L 774.21165,467.14054 L 778.02066,477.26954 L 783.46891,487.01806 L 787.26618,493.5731 L 792.21913,499.28775 L 796.34659,503.15354 L 797.99758,506.17894 L 796.84189,507.52356 L 796.0164,508.86819 L 798.98817,516.59977 L 801.95994,519.62517 L 804.60152,525.17175 L 808.23368,531.22255 L 812.85644,539.79453 L 814.17723,547.69419 L 814.67252,560.13195 L 815.33292,561.98081 L 815.00272,565.51045 L 812.52624,566.85507 L 812.85644,568.87201 L 812.19605,570.88894 L 812.52624,573.41011 L 813.02154,575.42704 L 810.21487,578.7886 L 807.078,580.3013 L 803.11563,580.46938 L 801.62975,582.15016 L 799.15327,583.15863 L 797.83248,582.6544 L 796.67679,581.64593 L 796.34659,578.62053 L 795.5211,575.09089 L 792.05403,569.7124 L 788.42187,567.3593 L 784.4595,567.02315 L 783.63401,568.36777 L 780.49714,563.82967 L 779.83675,560.13195 L 777.19517,555.93001 L 775.37909,554.75346 L 773.7281,556.93847 L 771.91202,556.60232 L 769.76574,551.3919 L 766.79397,547.35803 L 763.8222,541.81146 L 761.18062,538.61798 L 757.54845,534.75219 L 759.69473,532.23102 L 762.9967,526.51637 L 762.83161,524.83559 L 758.20885,523.82712 L 756.55786,524.49943 L 756.88806,525.17175 L 759.52964,526.18021 L 758.04375,530.8864 L 757.21826,531.39063 L 755.40217,527.18868 L 754.08139,522.14634 L 753.75119,519.28902 L 755.23708,514.41476 L 755.23708,504.49816 L 752.1002,500.63237 L 750.77942,497.43889 L 745.49627,496.09427 L 743.51508,495.42195 L 741.8641,492.73271 L 738.39703,491.05193 L 737.24134,487.52229 L 734.43467,486.51382 L 731.95819,482.64803 L 727.66563,481.13533 L 724.69386,479.62263 L 722.05228,479.62263 L 717.92482,480.46302 L 717.75972,482.47995 L 718.58522,483.48842 L 718.08992,484.66497 L 714.95305,484.49689 L 711.15578,488.1946 L 707.52362,490.21154 L 703.56126,490.21154 L 700.25929,491.55616 L 699.92909,488.69884 L 698.2781,486.6819 L 695.30633,485.50536 L 693.65535,483.99266 L 685.40042,479.95879 L 677.6408,478.10993 L 673.18314,478.78224 L 667.07449,479.28647 L 660.96585,481.47149 L 657.41261,482.10878 L 657.16963,473.73948 L 654.52806,471.72255 L 652.71197,469.87369 L 653.04217,466.6802 L 663.44338,465.33558 L 689.52898,462.31017 L 696.46313,461.63786 L 702.73688,461.46977 L 705.37846,465.50365 L 706.86434,467.01635 L 714.95419,467.18443 L 726.00404,466.51212 L 747.97393,465.1675 L 753.53546,464.46636 L 758.21005,464.49519 L 758.37515,467.52059 L 761.01673,468.36098 L 761.34692,463.82287 L 759.69594,459.11668 L 760.85163,457.4359 L 766.79518,458.27629 L 772.07835,458.61245 z M 784.71002,597.19259 L 787.18651,596.52028 L 788.5073,596.26817 L 789.99319,593.83102 L 792.38713,592.15024 L 793.70792,592.65448 L 795.44146,592.99063 L 795.8542,594.08315 L 792.30458,595.34374 L 788.012,596.85644 L 785.61807,598.11703 L 784.71002,597.19259 z M 798.49579,591.98217 L 799.73403,593.07468 L 802.54072,590.88965 L 807.98899,586.51962 L 811.78627,582.48573 L 814.3453,575.59451 L 815.3359,573.82969 L 815.501,570.30004 L 814.75805,570.80427 L 813.76746,573.74564 L 812.28156,578.53588 L 808.97958,583.99844 L 804.52191,588.36847 L 801.05483,590.38542 L 798.49579,591.98217 z \",\n    \"M 777.85557,425.66962 L 776.04071,426.6776 L 773.39913,425.33297 L 772.73874,423.14795 L 771.41795,419.45024 L 769.10656,417.26521 L 766.46499,416.5929 L 764.814,411.55057 L 762.00732,405.33167 L 757.71476,403.31473 L 755.56847,401.29779 L 754.24768,398.60854 L 752.1014,396.5916 L 749.79002,395.24697 L 747.47863,392.22157 L 744.34176,389.86848 L 739.71899,388.01961 L 739.2237,386.50691 L 736.74722,383.48151 L 736.25192,381.9688 L 732.78485,376.5903 L 729.31778,376.75838 L 725.19031,374.2372 L 723.86952,372.89258 L 723.53932,371.04372 L 724.36481,369.02679 L 726.67619,368.01831 L 726.346,365.8333 L 732.61975,363.14405 L 741.86527,358.43786 L 749.29471,357.59747 L 766.13479,357.09323 L 768.44617,359.11017 L 770.09715,362.47174 L 774.55482,361.9675 L 787.43252,360.45479 L 790.4043,361.29519 L 803.282,369.19486 L 813.60504,377.63896 L 808.06859,383.31398 L 805.42701,389.70094 L 804.93171,396.25598 L 803.28073,397.09637 L 802.12504,399.95369 L 799.64856,400.62601 L 797.50228,404.32372 L 794.69561,407.18104 L 792.38423,410.71068 L 790.73325,411.55107 L 787.10108,415.08071 L 784.12931,415.24879 L 785.1199,418.61034 L 780.00185,424.32499 L 777.85557,425.66962 z \",\n    \"M 704.71806,368.52255 L 699.7651,369.36294 L 691.17997,370.53949 L 682.42974,371.46391 L 682.42974,373.73297 L 682.59484,375.91799 L 683.25523,379.44763 L 686.72231,387.68346 L 689.19879,397.93623 L 690.68467,404.3232 L 692.33566,409.36554 L 693.82155,416.5929 L 695.96784,423.14795 L 698.60941,426.6776 L 699.10471,430.20724 L 701.0859,431.04763 L 701.251,433.23265 L 699.4349,438.27499 L 698.93961,441.63656 L 698.77451,443.65349 L 700.4255,448.19161 L 700.7557,453.73818 L 699.9302,456.25936 L 700.5906,457.09975 L 702.07649,457.94014 L 702.73688,461.46977 L 705.37846,465.50365 L 706.86434,467.01635 L 714.95419,467.18443 L 726.00404,466.51212 L 747.97393,465.1675 L 753.53546,464.46636 L 758.21005,464.49519 L 758.37515,467.52059 L 761.01673,468.36098 L 761.34692,463.82287 L 759.69594,459.11668 L 760.85163,457.4359 L 766.79518,458.27629 L 771.87844,458.60669 L 771.08653,452.05785 L 773.39791,441.63702 L 774.88379,437.26699 L 774.3885,434.57775 L 778.51596,427.3504 L 777.90454,425.66937 L 776.04071,426.6776 L 773.39913,425.33297 L 772.73874,423.14795 L 771.41795,419.45024 L 769.10656,417.26521 L 766.46499,416.5929 L 764.814,411.55057 L 762.00732,405.33167 L 757.71476,403.31473 L 755.56847,401.29779 L 754.24768,398.60854 L 752.1014,396.5916 L 749.79002,395.24697 L 747.47863,392.22157 L 744.34176,389.86848 L 739.71899,388.01961 L 739.2237,386.50691 L 736.74722,383.48151 L 736.25192,381.9688 L 732.78485,376.5903 L 729.31778,376.75838 L 725.19031,374.2372 L 723.86952,372.89258 L 723.53932,371.04372 L 724.36481,369.02679 L 726.67619,368.01831 L 726.51109,365.64481 L 724.69501,366.16945 L 718.75146,367.17792 L 711.65221,368.01831 L 704.71806,368.52255 z \",\n    \"M 639.33795,481.63956 L 637.68799,465.83981 L 634.88131,446.34274 L 635.04641,431.71994 L 635.8719,399.44893 L 635.7068,382.13688 L 635.87539,375.46299 L 643.79664,375.07759 L 672.19362,372.38834 L 682.58068,371.46391 L 682.42974,373.73297 L 682.59484,375.91799 L 683.25523,379.44763 L 686.72231,387.68346 L 689.19879,397.93623 L 690.68467,404.3232 L 692.33566,409.36554 L 693.82155,416.5929 L 695.96784,423.14795 L 698.60941,426.6776 L 699.10471,430.20724 L 701.0859,431.04763 L 701.251,433.23265 L 699.4349,438.27499 L 698.93961,441.63656 L 698.77451,443.65349 L 700.4255,448.19161 L 700.7557,453.73818 L 699.9302,456.25936 L 700.5906,457.09975 L 702.07649,457.94014 L 702.90198,461.63786 L 696.46313,461.63786 L 689.52898,462.31017 L 663.44338,465.33558 L 653.04217,466.6802 L 652.71197,469.87369 L 654.52806,471.72255 L 657.16963,473.73948 L 657.76284,481.98993 L 651.05994,484.66497 L 648.25327,484.32881 L 651.05994,482.31188 L 651.05994,481.30341 L 647.92307,475.08453 L 645.61169,474.41221 L 644.12581,478.95032 L 642.80502,481.80764 L 642.14462,481.63956 L 639.33795,481.63956 z \",\n    \"M 850.23842,306.65958 L 851.98478,311.54471 L 855.61694,318.26782 L 858.09342,320.78899 L 858.75382,323.14208 L 856.27734,323.31016 L 857.10283,323.98247 L 856.77263,328.3525 L 854.13106,329.69712 L 853.47066,331.88214 L 852.14988,334.90754 L 848.35261,336.58832 L 845.87614,336.25216 L 844.39025,336.08408 L 842.73926,334.73946 L 843.06946,336.08408 L 843.06946,337.09255 L 845.05064,337.09255 L 845.87614,338.43717 L 843.89495,344.99221 L 848.18751,344.99221 L 848.84791,346.67299 L 851.15929,344.3199 L 852.48007,343.81567 L 850.49889,347.51338 L 847.36202,352.55572 L 846.04123,352.55572 L 844.88554,352.05149 L 842.07887,352.7238 L 836.79572,355.24497 L 830.19178,360.79154 L 826.72471,365.6658 L 824.74353,372.38892 L 824.24824,374.91008 L 819.46038,375.41432 L 813.43993,377.723 L 803.282,369.19486 L 790.4043,361.29519 L 787.43252,360.45479 L 774.55482,361.9675 L 770.09715,362.47174 L 768.44617,359.11017 L 766.13479,357.09323 L 749.29471,357.59747 L 741.86527,358.43786 L 732.61975,363.14405 L 726.346,365.8333 L 724.69501,366.16945 L 718.75146,367.17792 L 711.65221,368.01831 L 704.71806,368.52255 L 705.04826,363.4802 L 706.86434,361.9675 L 709.67103,361.29519 L 710.33142,357.42939 L 714.62399,354.57206 L 718.58636,353.05935 L 722.87893,349.36164 L 727.33659,347.17662 L 727.99698,343.98313 L 731.95935,339.94926 L 732.61975,339.78119 C 732.61975,339.78119 732.61975,340.95773 733.44524,340.95773 C 734.27073,340.95773 735.42643,341.29389 735.42643,341.29389 L 737.73781,337.59616 L 739.88409,336.92385 L 742.19547,337.26001 L 743.84646,333.56229 L 746.81824,330.87303 L 747.31353,328.68802 L 747.31353,324.57011 L 751.9363,325.32646 L 759.22415,323.98183 L 775.38031,321.96489 L 792.88078,319.27565 L 813.92151,315.35219 L 833.49506,311.37597 L 845.21707,308.35056 L 850.23842,306.65958 z M 854.21672,340.95692 L 856.85831,338.3517 L 860.07773,335.66244 L 861.64617,334.99013 L 861.81127,332.88915 L 861.15088,326.50217 L 859.66499,324.06503 L 859.00459,322.13213 L 859.74753,321.88001 L 862.55422,327.59468 L 862.96697,332.21684 L 862.80187,335.74649 L 859.33479,337.34323 L 856.44555,339.86441 L 855.28987,341.125 L 854.21672,340.95692 z \",\n    \"M 712.3126,329.69649 L 659.31592,334.90691 L 643.2212,336.75577 L 638.50172,337.28883 L 634.55111,337.26001 L 634.55111,341.29389 L 625.96598,341.79812 L 618.86673,342.47043 L 607.53473,342.52544 L 607.26436,348.59252 L 605.08072,355.11718 L 604.06449,358.25292 L 602.68706,362.80789 L 602.35687,365.49714 L 598.22939,367.85023 L 599.71528,371.54796 L 598.72469,376.08606 L 597.15628,377.85089 L 605.49374,377.76685 L 630.09345,375.74991 L 635.54175,375.58184 L 643.79664,375.07759 L 672.19362,372.38834 L 682.58068,371.54796 L 691.17997,370.53949 L 699.7651,369.36294 L 704.71806,368.52255 L 705.04826,363.4802 L 706.86434,361.9675 L 709.67103,361.29519 L 710.33142,357.42939 L 714.62399,354.57206 L 718.58636,353.05935 L 722.87893,349.36164 L 727.33659,347.17662 L 727.99698,343.98313 L 731.95935,339.94926 L 732.61975,339.78119 C 732.61975,339.78119 732.61975,340.95773 733.44524,340.95773 C 734.27073,340.95773 735.42643,341.29389 735.42643,341.29389 L 737.73781,337.59616 L 739.88409,336.92385 L 742.19547,337.26001 L 743.84646,333.56229 L 746.81824,330.87303 L 747.31353,328.68802 L 747.49366,324.59981 L 745.16725,324.65414 L 742.69078,326.67109 L 734.60093,326.83916 L 722.3505,328.8153 L 712.3126,329.69649 z \",\n    \"M 893.09433,183.30123 L 892.6011,178.92994 L 891.77561,174.39182 L 890.04208,168.25697 L 895.90308,166.66023 L 897.55407,167.83677 L 901.02115,172.37489 L 903.99187,176.99768 L 901.01902,178.59507 L 899.69824,178.42699 L 898.54255,180.27585 L 896.06607,182.29279 L 893.09433,183.30123 z \",\n    \"M 893.58963,183.30123 L 892.6011,178.92994 L 891.77561,174.39182 L 890.12463,168.17293 L 884.84146,169.34947 L 862.55312,174.30778 L 863.21351,177.75339 L 864.6994,185.31692 L 864.6994,193.72083 L 863.54371,196.07393 L 865.41508,198.26677 L 870.47581,194.73055 L 874.10797,191.36899 L 876.08916,189.18398 L 876.91465,189.85629 L 879.72132,188.34359 L 885.00447,187.16705 L 893.58963,183.30123 z \",\n    \"M 919.55232,177.09192 L 921.77043,176.37882 L 922.23741,174.59609 L 923.28809,174.71493 L 924.33877,177.09192 L 923.0546,177.56732 L 919.08535,177.68617 L 919.55232,177.09192 z M 909.97943,177.92387 L 912.31427,175.19033 L 913.94868,175.19033 L 915.81656,176.73537 L 913.36497,177.80501 L 911.14686,178.87466 L 909.97943,177.92387 z M 874.44023,155.06282 L 892.27091,150.69278 L 894.5823,150.02047 L 896.72858,146.65891 L 900.54482,144.92957 L 903.4955,149.51759 L 901.01902,154.89608 L 900.68883,156.40879 L 902.67001,159.09803 L 903.8257,158.25764 L 905.64178,158.25764 L 907.95316,160.94689 L 911.91552,167.16577 L 915.54769,167.67001 L 917.85907,166.66154 L 919.67515,164.81268 L 918.84966,161.95536 L 916.70338,160.27458 L 915.21749,161.11497 L 914.2269,159.77034 L 914.7222,159.26611 L 916.86848,159.09803 L 918.68456,159.93842 L 920.66574,162.45959 L 921.65633,165.48499 L 921.98653,168.00616 L 917.69397,169.51886 L 913.73161,171.5358 L 909.76924,176.24198 L 907.78806,177.75468 L 907.78806,176.74621 L 910.26454,175.23351 L 910.75983,173.38466 L 909.93434,170.19118 L 906.96257,171.70388 L 906.13708,173.21658 L 906.63237,175.56967 L 903.82678,177.08172 L 901.02115,172.37489 L 897.55407,167.83677 L 895.90308,166.66023 L 890.04208,168.25697 L 884.84146,169.34947 L 862.55312,174.30778 L 861.56253,168.34101 L 862.22292,157.33189 L 867.50608,156.40745 L 874.44023,155.06282\",\n    \"M 943.28423,76.73985 L 945.26541,78.924863 L 947.57679,82.790656 L 947.57679,84.807591 L 945.43051,89.68185 L 943.44933,90.354162 L 939.98226,93.547643 L 935.02931,99.262292 C 935.02931,99.262292 934.36891,99.262292 933.70852,99.262292 C 933.04813,99.262292 932.71793,97.077279 932.71793,97.077279 L 930.90185,97.245357 L 929.91126,98.758058 L 927.43478,100.27076 L 926.44419,101.78346 L 928.09517,103.29616 L 927.59988,103.96847 L 927.10458,106.8258 L 925.1234,106.65772 L 925.1234,104.97694 L 924.7932,103.63232 L 923.30732,103.96847 L 921.49123,100.60692 L 919.34495,101.95154 L 920.66574,103.46424 L 920.99594,104.64079 L 920.17045,105.98541 L 920.50064,109.17889 L 920.66574,110.85967 L 919.01476,113.54892 L 916.04298,114.05315 L 915.71279,117.07855 L 910.26454,120.27203 L 908.94375,120.77627 L 907.29277,119.26356 L 904.15589,122.96128 L 905.14649,126.32284 L 903.6606,127.66746 L 903.4955,132.20556 L 901.88477,140.12915 L 899.37016,138.9273 L 898.87486,135.73381 L 894.91249,134.55727 L 894.5823,131.69993 L 887.15284,107.32858 L 882.28553,91.967581 L 884.77927,91.608771 L 886.32526,92.034941 L 886.32526,89.345695 L 887.15075,83.631045 L 889.79233,78.756786 L 891.27821,74.554837 L 889.29703,72.033669 L 889.29703,65.814786 L 890.12252,64.806318 L 890.94802,61.948993 L 890.78292,60.436292 L 890.61782,55.393954 L 892.4339,50.351617 L 895.40568,41.107331 L 897.55196,36.737305 L 898.87274,36.737305 L 900.19353,36.905383 L 900.19353,38.081928 L 901.51432,40.435019 L 904.32099,41.107331 L 905.14649,40.266941 L 905.14649,39.258474 L 909.27395,36.233071 L 911.09003,34.384214 L 912.57592,34.552292 L 918.68456,37.073461 L 920.66574,38.081928 L 929.91126,69.176344 L 936.0199,69.176344 L 936.84539,71.193279 L 937.01049,76.235617 L 939.98226,78.588708 L 940.80775,78.588708 L 940.97285,78.084474 L 940.47756,76.907928 L 943.28423,76.73985 z M 921.90732,108.08415 L 923.47577,106.48741 L 924.87911,107.57992 L 925.45696,110.1011 L 923.72342,111.02553 L 921.90732,108.08415 z M 928.75894,101.94929 L 930.57502,103.88219 C 930.57502,103.88219 931.89582,103.96623 931.89582,103.63007 C 931.89582,103.29391 932.14346,101.52909 932.14346,101.52909 L 933.05151,100.6887 L 932.22602,98.839833 L 930.16228,99.596189 L 928.75894,101.94929 z \",\n    \"M 900.54588,144.88986 L 900.85393,143.29871 L 901.96733,139.87704 L 899.37016,138.9273 L 898.87486,135.73381 L 894.91249,134.55727 L 894.5823,131.69993 L 887.15284,107.32858 L 882.45357,92.208279 L 881.5374,92.203019 L 880.87701,93.883799 L 880.21662,93.379565 L 879.22603,92.371097 L 877.74014,94.388032 L 876.76354,100.09176 L 877.08182,105.98396 L 879.063,108.84129 L 879.063,113.04325 L 875.26572,117.2452 L 872.62415,118.42176 L 872.62415,119.5983 L 873.77984,121.44716 L 873.77984,130.35531 L 872.95434,139.93577 L 872.78925,144.97812 L 873.77984,146.32275 L 873.61474,151.02894 L 873.11944,152.8778 L 874.60533,154.97877 L 892.27091,150.69278 L 894.5823,150.02047 L 896.72858,146.65891 L 900.54588,144.88986 z \",\n    \"M 862.38802,157.584 L 861.56253,151.70126 L 858.42565,140.27193 L 857.76525,139.93577 L 854.79347,138.59115 L 855.61896,135.56574 L 854.79347,133.38072 L 852.1519,128.67453 L 853.14249,124.64065 L 852.31699,119.26214 L 849.84051,112.53901 L 849.0178,107.42109 L 876.75058,99.933872 L 877.08182,105.98396 L 879.063,108.84129 L 879.063,113.04325 L 875.26572,117.2452 L 872.62415,118.42176 L 872.62415,119.5983 L 873.77984,121.44716 L 873.77984,130.35531 L 872.95434,139.93577 L 872.78925,144.97812 L 873.77984,146.32275 L 873.61474,151.02894 L 873.11944,152.8778 L 874.60533,154.97877 L 867.50608,156.40745 L 862.38802,157.584 z \",\n    \"M 846.20833,194.22506 L 845.05264,193.21659 L 842.41105,193.04851 L 840.09968,191.03158 L 837.62319,185.485 L 834.55471,184.51732 L 832.17493,182.29151 L 813.18856,186.49346 L 769.27227,195.56969 L 760.19184,197.08239 L 759.43798,189.88537 L 762.17121,188.00743 L 763.492,186.83089 L 764.48259,185.15011 L 766.29867,183.97356 L 768.27985,182.12471 L 768.77515,180.44393 L 770.92143,177.5866 L 772.07712,176.57814 L 771.91202,175.56967 L 770.59123,172.37619 L 768.77515,172.20811 L 766.79397,165.82115 L 769.76574,163.97229 L 774.2234,162.45959 L 778.35086,161.11497 L 781.65283,160.61073 L 788.09167,160.44266 L 790.07285,161.78728 L 791.72384,161.95536 L 793.87012,160.61073 L 796.51169,159.43419 L 801.79484,158.92995 L 803.94112,157.0811 L 805.75721,153.71954 L 807.40819,151.7026 L 809.55447,151.7026 L 811.53565,150.52606 L 811.70075,148.17297 L 810.21487,145.98795 L 809.88467,144.47525 L 811.04036,142.29024 L 811.04036,140.77754 L 809.22428,140.77754 L 807.40819,139.93715 L 806.5827,138.7606 L 806.4176,136.07136 L 812.36115,130.35671 L 813.02154,129.51632 L 814.50743,126.49092 L 817.4792,121.78473 L 820.28587,117.91894 L 822.43215,115.39777 L 824.89861,113.49969 L 828.0455,112.20429 L 833.65885,110.85967 L 836.96082,111.02775 L 841.58358,109.51505 L 849.30966,107.36166 L 849.84051,112.53901 L 852.31699,119.26214 L 853.14249,124.64065 L 852.1519,128.67453 L 854.79347,133.38072 L 855.61896,135.56574 L 854.79347,138.59115 L 857.76525,139.93577 L 858.42565,140.27193 L 861.56253,151.70126 L 862.05782,157.07976 L 861.56253,168.34101 L 862.38802,174.05567 L 863.21351,177.75339 L 864.6994,185.31692 L 864.6994,193.72083 L 863.54371,196.07393 L 865.42216,198.14582 L 865.19266,199.77289 L 863.21147,201.62175 L 863.54167,202.96637 L 864.86246,202.63021 L 866.34835,201.28559 L 868.65972,198.59634 L 869.81541,197.92403 L 871.4664,198.59634 L 873.77778,198.76442 L 881.8676,194.73055 L 884.83937,191.87323 L 886.16016,190.36053 L 890.45272,192.0413 L 886.98565,195.73902 L 883.02329,198.76442 L 875.75896,204.31099 L 873.11738,205.31946 L 867.17384,207.3364 L 863.04638,208.51294 L 861.49899,207.95886 L 860.90212,204.47784 L 861.39742,201.62051 L 861.23232,199.4355 L 858.59075,198.25894 L 853.96798,197.25047 L 850.0056,196.07393 L 846.20833,194.22506 z \",\n    \"M 846.20833,194.22506 L 844.06205,196.74624 L 844.06205,199.93973 L 842.08086,203.13321 L 841.91576,204.814 L 843.23656,206.15862 L 843.07146,208.6798 L 840.76007,209.85635 L 841.58556,212.71367 L 841.75066,213.89023 L 844.55734,214.22639 L 845.54794,216.91563 L 849.18011,219.43681 L 851.65659,221.11759 L 851.65659,221.95798 L 848.35462,225.15147 L 846.70362,227.50456 L 845.21774,230.3619 L 842.90636,231.70652 L 841.66812,232.46288 L 841.42046,233.72347 L 840.79828,236.43369 L 841.91377,238.76697 L 845.21574,241.79237 L 850.1687,244.14546 L 854.29616,244.81777 L 854.46126,246.33047 L 853.63576,247.33894 L 853.96596,250.19627 L 854.79145,250.19627 L 856.93773,247.6751 L 857.76322,242.63276 L 860.5699,238.43081 L 863.70677,231.70769 L 864.86246,225.99305 L 864.20207,224.8165 L 864.03697,215.06798 L 862.38598,211.53834 L 861.23029,212.37873 L 858.42362,212.71489 L 857.92832,212.21066 L 859.08401,211.20219 L 861.23029,209.18525 L 861.29469,208.048 L 860.90212,204.47784 L 861.39742,201.62051 L 861.23232,199.4355 L 858.59075,198.25894 L 853.96798,197.25047 L 850.0056,196.07393 L 846.20833,194.22506 z \",\n    \"M 841.75066,232.37883 L 842.90636,231.70652 L 845.21774,230.3619 L 846.70362,227.50456 L 848.35462,225.15147 L 851.65659,221.95798 L 851.65659,221.11759 L 849.18011,219.43681 L 845.54794,216.91563 L 844.55734,214.22639 L 841.75066,213.89023 L 841.58556,212.71367 L 840.76007,209.85635 L 843.07146,208.6798 L 843.23656,206.15862 L 841.91576,204.814 L 842.08086,203.13321 L 844.06205,199.93973 L 844.06205,196.74624 L 846.45598,194.22507 L 845.05264,193.21659 L 842.41105,193.04851 L 840.09968,191.03158 L 837.62319,185.485 L 834.55471,184.51732 L 832.17493,182.29151 L 813.18856,186.49346 L 769.27227,195.56969 L 760.19184,197.08239 L 759.68563,189.71729 L 754.08139,195.57094 L 752.7606,196.07518 L 748.46894,199.20351 L 751.4416,219.10066 L 753.16482,230.27806 L 756.81257,250.30417 L 761.54207,249.5232 L 773.73965,247.96108 L 812.47286,239.9916 L 827.66544,237.0562 L 836.14231,235.36944 L 837.45809,234.05962 L 839.60438,232.37883 L 841.75066,232.37883 z \",\n    \"M 840.59298,235.90964 L 841.42046,233.72347 L 841.66812,232.37883 L 839.60438,232.37883 L 837.45809,234.05962 L 835.9722,235.57232 L 837.45809,239.94236 L 839.76948,245.8251 L 841.91576,255.9098 L 843.56675,262.46486 L 848.68482,262.29678 L 854.95755,261.03674 L 852.64517,253.38975 L 851.65458,253.89398 L 848.02242,251.37281 L 846.20633,246.49855 L 844.22515,242.80084 L 841.91377,241.79237 L 839.76749,238.09466 L 840.59298,235.90964 z \",\n    \"M 854.95655,260.95325 L 848.68482,262.29678 L 843.56675,262.46486 L 841.91576,255.9098 L 839.76948,245.8251 L 837.45809,239.94236 L 836.14231,235.36944 L 827.66544,237.0562 L 812.47286,239.9916 L 774.22495,247.84224 L 775.38031,253.05285 L 776.37091,258.93558 L 776.7011,258.59942 L 778.84739,256.07825 L 781.15877,252.88476 L 783.63525,252.71668 L 785.12115,251.20398 L 786.93723,248.51473 L 788.25802,249.18705 L 791.22979,248.85089 L 793.87137,246.66588 L 795.92094,245.15492 L 797.80542,244.65068 L 799.48473,245.82549 L 802.45651,247.33819 L 804.43769,249.18705 L 805.67593,250.78379 L 809.88595,252.5486 L 809.88595,255.57402 L 815.49931,256.91864 L 817.48049,258.26326 L 818.47108,256.24633 L 820.78247,257.92711 L 819.29657,261.28868 L 818.96637,264.146 L 817.15029,266.83525 L 817.15029,269.02027 L 817.81068,270.86913 L 822.98233,272.27864 L 827.38511,272.21447 L 830.52198,273.22294 L 832.66826,273.5591 L 833.65885,271.37408 L 832.17296,269.18907 L 832.17296,267.34021 L 829.69649,265.1552 L 827.55021,259.44055 L 828.87099,253.89398 L 828.70589,251.70897 L 827.38511,250.36434 C 827.38511,250.36434 828.87099,248.68356 828.87099,248.01125 C 828.87099,247.33894 829.36629,245.82624 829.36629,245.82624 L 831.34747,244.48162 L 833.32865,242.80084 L 833.82395,243.8093 L 832.33806,245.49008 L 831.01727,249.35588 L 831.34747,250.53242 L 833.16355,250.86858 L 833.65885,256.58323 L 831.51257,257.59169 L 831.84277,261.28941 L 832.33806,261.12133 L 833.49375,259.1044 L 835.14473,260.95325 L 833.49375,262.29788 L 833.16355,265.82751 L 835.80513,269.35715 L 839.76749,269.86138 L 841.41848,269.02099 L 844.72045,274.39949 L 846.53653,274.90372 L 846.53653,278.60143 L 844.22515,283.64377 L 843.72986,290.87112 L 845.21574,294.40076 L 846.70163,294.56884 L 848.68281,290.19881 L 849.5083,286.5011 L 849.6734,279.10567 L 852.81027,274.06333 L 854.95655,266.83598 L 854.95655,260.95325 z M 838.20212,271.12031 L 839.3578,273.72552 L 839.5229,275.57439 L 840.67859,277.50729 C 840.67859,277.50729 841.58664,276.58285 841.58664,276.2467 C 841.58664,275.91054 840.8437,273.05321 840.8437,273.05321 L 840.10075,270.61606 L 838.20212,271.12031 z \",\n    \"M 774.24466,247.91204 L 775.38031,253.05285 L 776.37091,258.93558 L 776.7011,258.59942 L 778.84739,256.07825 L 781.15877,252.88476 L 783.63525,252.71668 L 785.12115,251.20398 L 786.93723,248.51473 L 788.25802,249.18705 L 791.22979,248.85089 L 793.87137,246.66588 L 795.92094,245.15492 L 797.80542,244.65068 L 799.48473,245.82549 L 802.45651,247.33819 L 804.43769,249.18705 L 805.84103,250.53167 L 804.7679,255.7421 L 798.98943,252.5486 L 794.36667,250.69975 L 794.20157,256.24633 L 793.70628,258.43134 L 792.05529,261.28868 L 791.39489,262.96946 L 788.25802,265.49063 L 787.76272,267.84373 L 784.29564,268.17988 L 783.96545,271.37336 L 782.80976,277.08802 L 780.16818,277.08802 L 778.84739,276.24763 L 777.1964,273.3903 L 775.38031,273.55838 L 775.05012,278.09649 L 772.90384,284.9877 L 767.78577,296.24894 L 768.61127,297.59356 L 768.44617,300.45089 L 766.29989,302.46782 L 764.814,302.13167 L 761.51202,304.65285 L 758.87045,303.64438 L 757.05436,308.51864 C 757.05436,308.51864 753.25709,309.35903 752.59669,309.52711 C 751.9363,309.69518 750.12022,308.18248 750.12022,308.18248 L 747.64373,310.53557 L 745.00215,311.2079 L 742.03037,310.36749 L 740.70958,309.02287 L 738.47074,305.8795 L 735.26132,303.81246 L 732.61975,300.95512 L 729.64798,297.08933 L 728.98758,294.73623 L 726.346,293.22353 L 725.5205,291.54275 L 725.27285,286.0802 L 727.50168,285.99616 L 729.48288,285.15577 L 729.64798,282.29845 L 731.29896,280.78574 L 731.46406,275.57532 L 732.45465,271.54144 L 733.77544,270.86913 L 735.09623,272.04567 L 735.59153,273.89453 L 737.40761,272.88606 L 737.90291,271.20529 L 736.74722,269.35643 L 736.74722,266.83525 L 737.73781,265.49063 L 740.04919,261.96099 L 741.36998,260.44829 L 743.51627,260.95252 L 745.82765,259.27173 L 748.96452,255.7421 L 751.27591,251.70821 L 751.6061,245.82549 L 752.1014,240.61506 L 752.1014,235.74079 L 750.94571,232.54731 L 751.9363,231.0346 L 753.24707,229.68997 L 756.81257,250.30417 L 761.54207,249.5232 L 774.24466,247.91204 z\",\n    \"M 738.61165,306.09768 L 735.42643,309.35903 L 731.13386,313.05675 L 726.51109,318.60333 L 724.69501,320.45219 L 724.69501,322.6372 L 720.73264,324.82222 L 714.95419,328.35186 L 712.28688,329.81359 L 659.31592,334.90691 L 643.2212,336.75577 L 638.50172,337.28883 L 634.55111,337.26001 L 634.55111,341.29389 L 625.96598,341.79812 L 618.86673,342.47043 L 608.21432,342.68419 L 609.24067,341.39196 L 611.46709,339.55999 L 613.56845,338.3715 L 613.80194,335.04372 L 614.73588,333.14213 L 613.09488,330.50244 L 613.91377,328.51994 L 616.22516,326.67109 L 618.37144,325.99877 L 621.17811,327.3434 L 624.81029,328.68802 L 625.96598,328.35186 L 626.13108,325.99877 L 624.81029,323.47759 L 625.14049,321.1245 L 627.12167,319.6118 L 629.76325,318.93949 L 631.41424,318.26718 L 630.58875,316.41831 L 629.92835,314.40138 L 631.08404,313.56099 L 632.15718,310.11537 L 635.2115,308.35056 L 641.15506,307.34209 L 644.78724,306.83786 L 646.27312,308.85479 L 648.08921,309.69518 L 649.90529,306.33362 L 652.87707,304.82092 L 654.85825,306.5017 L 655.68375,307.67825 L 657.83004,307.17401 L 657.66493,303.64438 L 660.63671,301.96359 L 661.7924,301.1232 L 662.94809,302.80398 L 667.73595,302.80398 L 668.56145,300.61896 L 668.23125,298.26587 L 671.20302,294.56815 L 675.99089,290.53428 L 676.48618,285.82809 L 679.29287,285.49193 L 683.25523,283.64307 L 686.06192,281.62613 L 685.73171,279.60919 L 684.24582,278.09649 L 684.82367,275.82744 L 689.03369,275.57532 L 691.51017,274.73493 L 694.48195,276.41571 L 696.13293,280.95382 L 702.07649,281.28997 L 703.89257,283.13884 L 706.03885,283.30692 L 708.51534,281.79422 L 711.65221,282.29845 L 712.973,283.81115 L 715.77968,281.12189 L 717.59577,279.77727 L 719.24675,279.77727 L 719.90714,282.63461 L 721.72324,283.64307 L 725.3554,285.82809 L 725.5205,291.54275 L 726.346,293.22353 L 728.98758,294.73623 L 729.64798,297.08933 L 732.61975,300.95512 L 735.26132,303.81246 L 738.61165,306.09768 z \",\n    \"M 748.46982,198.97029 L 741.20371,203.30253 L 737.24134,205.65562 L 733.77427,209.52141 L 729.64681,213.55528 L 726.34484,214.39567 L 723.37307,214.8999 L 717.75972,217.58915 L 715.61344,217.75723 L 712.14638,214.56375 L 706.86322,215.23606 L 704.22165,213.72336 L 701.78994,212.3189 L 696.79333,213.05024 L 686.39211,214.73102 L 678.46737,215.99161 L 679.78816,231.20268 L 681.60425,245.48932 L 684.24582,269.86066 L 684.82367,275.82744 L 689.03369,275.57532 L 691.51017,274.73493 L 694.48195,276.41571 L 696.13293,280.95382 L 702.07649,281.28997 L 703.89257,283.13884 L 706.03885,283.30692 L 708.51534,281.79422 L 711.65221,282.29845 L 712.973,283.81115 L 715.77968,281.12189 L 717.59577,279.77727 L 719.24675,279.77727 L 719.90714,282.63461 L 721.72324,283.64307 L 725.27285,286.0802 L 727.50168,285.99616 L 729.48288,285.15577 L 729.64798,282.29845 L 731.29896,280.78574 L 731.46406,275.57532 L 732.45465,271.54144 L 733.77544,270.86913 L 735.09623,272.04567 L 735.59153,273.89453 L 737.40761,272.88606 L 737.90291,271.20529 L 736.74722,269.35643 L 736.74722,266.83525 L 737.73781,265.49063 L 740.04919,261.96099 L 741.36998,260.44829 L 743.51627,260.95252 L 745.82765,259.27173 L 748.96452,255.7421 L 751.27591,251.70821 L 751.6061,245.82549 L 752.1014,240.61506 L 752.1014,235.74079 L 750.94571,232.54731 L 751.9363,231.0346 L 753.33994,230.27806 L 751.4416,219.10066 L 748.46982,198.97029 z \",\n    \"M 594.42414,81.655837 L 596.29202,79.516552 L 598.51013,78.684606 L 603.99703,74.643722 L 606.33188,74.049474 L 606.79885,74.524879 L 601.54544,79.873103 L 598.1599,81.893534 L 596.05854,82.844333 L 594.42414,81.655837 z M 682.43117,115.05941 L 683.09156,117.66462 L 686.39354,117.8327 L 687.71434,116.57211 C 687.71434,116.57211 687.63178,115.05941 687.30159,114.89133 C 686.97139,114.72326 685.6506,112.95843 685.6506,112.95843 L 683.42177,113.21054 L 681.77077,113.37862 L 681.44058,114.55518 L 682.43117,115.05941 z M 713.13697,180.61201 L 709.835,172.04003 L 707.52362,162.62767 L 705.04714,159.26611 L 702.40557,157.41725 L 700.75458,158.5938 L 696.79222,160.44266 L 694.81104,165.65307 L 692.00436,169.51886 L 690.84867,170.19118 L 689.36279,169.51886 C 689.36279,169.51886 686.72121,168.00616 686.88631,167.33385 C 687.05141,166.66154 687.38161,162.12343 687.38161,162.12343 L 690.84867,160.77881 L 691.67417,157.24918 L 692.33456,154.55993 L 694.81104,152.87915 L 694.48084,142.45832 L 692.82985,140.10523 L 691.50907,139.26484 L 690.68357,137.07982 L 691.50907,136.23943 L 693.16005,136.57559 L 693.32515,134.89481 L 690.84867,132.54172 L 689.52789,129.85247 L 686.88631,129.85247 L 682.26355,128.33977 L 676.6502,124.81014 L 673.84353,124.81014 L 673.18314,125.48245 L 672.19255,124.97821 L 669.05568,122.62512 L 666.0839,124.47398 L 663.11213,126.82707 L 663.44233,130.52479 L 664.43292,130.86094 L 666.5792,131.36518 L 667.07449,132.20556 L 664.43292,133.04595 L 661.79134,133.38211 L 660.30546,135.23097 L 659.97526,137.41598 L 660.30546,139.09676 L 660.63565,144.81141 L 657.00349,146.99642 L 656.34309,146.82834 L 656.34309,142.45832 L 657.66388,139.93715 L 658.32427,137.41598 L 657.49878,136.57559 L 655.5176,137.41598 L 654.52701,141.78601 L 651.72034,142.96255 L 649.90425,144.97949 L 649.73915,145.98795 L 650.39955,146.82834 L 649.73915,149.51759 L 647.42778,150.02182 L 647.42778,151.19837 L 648.25327,153.71954 L 647.09758,160.1065 L 645.44659,164.30845 L 646.10699,169.18271 L 646.60228,170.35925 L 645.77679,172.88042 L 645.44659,173.72081 L 645.1164,176.57814 L 648.74856,182.79702 L 651.72034,189.52014 L 653.20622,194.56247 L 652.38073,199.43673 L 651.39014,205.65562 L 648.91366,211.03411 L 648.58347,213.89143 L 645.43483,217.12572 L 644.67586,217.92491 L 649.40999,217.75643 L 671.86343,215.40333 L 678.13717,214.73102 L 678.46737,215.99161 L 686.39211,214.73102 L 696.79333,213.05024 L 702.12014,212.57103 L 700.75458,211.37027 L 700.91968,209.85756 L 703.06596,205.99177 L 705.10906,204.18493 L 704.88204,198.9325 L 706.51299,197.27212 L 707.62681,196.91556 L 707.85382,193.21785 L 709.42225,190.0664 L 710.49539,190.69668 L 710.66049,191.36899 L 711.48598,191.53707 L 713.46716,190.5286 L 713.13697,180.61201 z M 578.8376,112.43927 L 580.72799,111.3639 L 583.53467,110.52351 L 587.16683,108.17042 L 587.16683,107.16195 L 587.82723,106.48964 L 593.93587,105.48118 L 596.41235,103.46424 L 600.87001,101.27923 L 601.03511,99.934604 L 603.01629,96.909201 L 604.83237,96.068811 L 606.15316,94.219954 L 608.46454,91.866863 L 612.9222,89.345695 L 617.71005,88.841461 L 618.86574,90.018006 L 618.53554,91.026474 L 614.73828,92.034941 L 613.25239,95.228422 L 610.94101,96.068811 L 610.44572,98.58998 L 607.96924,101.95154 L 607.63904,104.64079 L 608.46454,105.14502 L 609.45513,103.96847 L 613.08729,100.94307 L 614.40808,102.28769 L 616.71946,102.28769 L 620.02143,103.29616 L 621.50732,104.47271 L 622.9932,107.66619 L 625.79988,110.52351 L 629.76224,110.35543 L 631.24813,109.34697 L 632.89911,110.69159 L 634.5501,111.19582 L 635.87088,110.35543 L 637.02657,110.35543 L 638.67756,109.34697 L 642.80502,105.64925 L 646.27209,104.47271 L 653.04112,104.13655 L 657.66388,102.11962 L 660.30546,100.77499 L 661.79134,100.94307 L 661.79134,106.8258 L 662.28664,107.16195 L 665.25841,108.00234 L 667.23959,107.49811 L 673.51333,105.81733 L 674.66902,104.64079 L 676.15491,105.14502 L 676.15491,112.37237 L 679.45688,115.56585 L 680.77767,116.23816 L 682.09845,117.24663 L 680.77767,117.58279 L 679.95217,117.24663 L 676.15491,116.7424 L 674.00863,117.41471 L 671.69725,117.24663 L 668.39528,118.75933 L 666.5792,118.75933 L 660.63565,117.41471 L 655.3525,117.58279 L 653.37132,120.27203 L 646.27209,120.94434 L 643.79561,121.78473 L 642.63992,124.97821 L 641.31913,126.15476 L 640.82384,125.98668 L 639.33795,124.3059 L 634.71519,126.82707 L 634.0548,126.82707 L 632.89911,125.14629 L 632.07362,125.31437 L 630.09244,129.85247 L 629.10185,134.05442 L 625.27363,142.51293 L 623.6083,141.31962 L 622.20739,139.89342 L 620.57299,129.197 L 616.83724,128.00851 L 615.43633,125.63153 L 602.59467,122.77914 L 600.02634,121.59066 L 591.62089,119.21367 L 583.21544,118.02518 L 578.8376,112.43927 z \",\n    \"M 363.20447,145.98954 L 351.44763,144.98362 L 318.67723,141.55738 L 302.09981,139.41809 L 273.14771,135.13952 L 252.83454,132.04945 L 251.38528,143.66906 L 247.4644,168.89268 L 242.09425,200.50655 L 240.53069,211.44019 L 238.82546,223.80098 L 245.48808,224.7662 L 262.73518,227.14318 L 271.75391,228.36645 L 292.76047,230.93187 L 330.81813,235.21041 L 355.80134,237.34972 L 360.23755,191.23625 L 361.87193,164.85174 L 363.20447,145.98954 z \",\n    \"M 365.51098,123.96764 L 366.33647,111.87386 L 368.64299,85.935913 L 370.0439,70.247815 L 371.33142,55.452236 L 338.69364,52.032396 L 308.81082,48.334682 L 278.92799,44.132734 L 245.9083,38.586162 L 227.08707,35.056526 L 193.6675,27.848581 L 189.09322,50.043547 L 192.59549,57.887585 L 191.19458,62.64155 L 193.06246,67.395514 L 196.33125,68.821708 L 200.067,79.518133 L 203.80276,83.321298 L 204.26973,84.509794 L 207.772,85.698291 L 208.23897,87.837565 L 201.00095,106.14034 L 201.00095,108.75502 L 203.56928,112.08279 L 204.50321,112.08279 L 209.40639,108.99272 L 210.10685,107.80422 L 211.74124,108.51732 L 211.50775,113.98438 L 214.30957,127.05779 L 217.34487,129.67247 L 218.2788,130.38556 L 220.14668,132.76254 L 219.67972,136.32802 L 220.38017,139.89349 L 221.5476,140.84429 L 223.88244,138.4673 L 226.68426,138.4673 L 229.95305,140.13119 L 232.52138,139.1804 L 236.7241,139.1804 L 240.45985,140.84429 L 243.26167,140.36889 L 243.72864,137.27881 L 246.76394,136.56572 L 248.16485,137.99191 L 248.63182,141.31968 L 251.26853,143.90677 L 252.83454,132.04945 L 273.14771,135.13952 L 302.09981,139.41809 L 318.67723,141.55738 L 351.44763,144.98362 L 363.16317,146.23449 L 364.89307,129.69427 L 365.51098,123.96764 z \",\n    \"M 144.08485,180.96023 L 148.93381,161.76187 L 153.37002,143.34026 L 154.77093,138.94284 L 157.33926,132.76269 L 156.0551,130.38571 L 153.48676,130.50455 L 152.66957,129.43491 L 153.13654,128.24642 L 153.48676,125.0375 L 158.03971,119.33273 L 159.90759,118.85734 L 161.07501,117.66885 L 161.65873,114.34107 L 162.59266,113.62798 L 166.5619,107.56668 L 170.53114,103.05041 L 170.76463,99.128389 L 167.26235,96.394856 L 165.91982,91.819167 L 166.32842,81.776422 L 170.06418,64.662142 L 174.61712,43.031605 L 178.46962,29.00742 L 179.24775,25.053259 L 193.6675,27.848581 L 189.09322,50.043547 L 192.59549,57.887585 L 191.19458,62.64155 L 193.06246,67.395514 L 196.33125,68.821708 L 200.067,79.518133 L 203.80276,83.321298 L 204.26973,84.509794 L 207.772,85.698291 L 208.23897,87.837565 L 201.00095,106.14034 L 201.00095,108.75502 L 203.56928,112.08279 L 204.50321,112.08279 L 209.40639,108.99272 L 210.10685,107.80422 L 211.74124,108.51732 L 211.50775,113.98438 L 214.30957,127.05779 L 217.34487,129.67247 L 218.2788,130.38556 L 220.14668,132.76254 L 219.67972,136.32802 L 220.38017,139.89349 L 221.5476,140.84429 L 223.88244,138.4673 L 226.68426,138.4673 L 229.95305,140.13119 L 232.52138,139.1804 L 236.7241,139.1804 L 240.45985,140.84429 L 243.26167,140.36889 L 243.72864,137.27881 L 246.76394,136.56572 L 248.16485,137.99191 L 248.63182,141.31968 L 251.31689,143.45897 L 247.4644,168.89268 L 242.21095,200.38777 L 237.30774,199.55589 L 228.78555,198.12969 L 218.27875,196.22811 L 206.02081,194.08882 L 193.0624,191.65242 L 184.89044,189.57255 L 175.43432,187.67098 L 165.51122,185.65054 L 144.08485,180.96023 z \",\n    \"M 95.99889,2.9536428 L 100.45655,4.4663441 L 110.36246,7.3236687 L 119.11268,9.3406038 L 139.58489,15.223331 L 163.02887,21.106058 L 179.49525,24.969183 L 178.46962,29.00742 L 174.61712,43.031605 L 170.06418,64.662142 L 166.32842,81.776422 L 166.13328,91.861195 L 151.85237,88.313121 L 136.44238,84.628799 L 120.68217,84.747642 L 120.21521,83.321459 L 114.61157,85.460744 L 110.05862,84.866496 L 107.60703,83.202605 L 106.32286,83.915707 L 101.53644,83.678 L 99.785303,82.251817 L 94.415149,80.112532 L 93.597952,80.231386 L 89.161743,78.686338 L 87.177124,80.587926 L 80.873036,80.231386 L 74.802439,75.952816 L 75.50289,75.12087 L 75.736374,67.039124 L 73.401527,62.998262 L 69.198802,62.404014 L 68.498351,59.789335 L 66.094359,59.304248 L 64.13488,57.747045 L 62.318797,58.755513 L 60.007419,55.73011 L 60.337616,52.704708 L 63.14429,52.368552 L 64.795274,48.166604 L 62.153699,46.990058 L 62.318797,43.124266 L 66.776456,42.451954 L 63.969782,39.59463 L 62.483896,32.199201 L 63.14429,29.173799 L 63.14429,20.93798 L 61.328206,17.576422 L 63.639585,7.8279025 L 65.785865,8.3321363 L 68.262342,11.357539 L 71.069016,14.046786 L 74.370985,16.063721 L 78.993743,18.248734 L 82.130616,18.921045 L 85.102388,20.433747 L 88.569459,21.442214 L 90.880838,21.274136 L 90.880838,18.752967 L 92.201625,17.576422 L 94.347905,16.231799 L 94.678102,17.408344 L 95.008299,19.257201 L 92.696921,19.761435 L 92.366724,21.946448 L 94.182807,23.459149 L 95.338496,25.980318 L 95.99889,27.997253 L 97.484776,27.829175 L 97.649875,26.484552 L 96.659284,25.139928 L 96.163989,21.77837 L 96.989481,19.929513 L 96.329087,18.416812 L 96.329087,16.063721 L 98.14517,12.366006 L 96.989481,9.6767597 L 94.513004,4.634422 L 94.843201,3.7940324 L 95.99889,2.9536428 z M 86.341086,9.169955 L 88.404826,9.001877 L 88.900121,10.430545 L 90.468562,8.7497548 L 92.862495,8.7497548 L 93.687987,10.3465 L 92.119546,12.111324 L 92.779951,12.951724 L 92.037002,15.052704 L 90.63366,15.472893 C 90.63366,15.472893 89.725613,15.556938 89.725613,15.220782 C 89.725613,14.884626 91.21151,12.531524 91.21151,12.531524 L 89.477971,11.943246 L 89.147774,13.455958 L 88.404826,14.12827 L 86.836382,11.775168 L 86.341086,9.169955 z \",\n    \"M 224.65378,521.59843 L 226.52879,518.16091 L 228.7163,517.84841 L 229.0288,518.62966 L 226.99754,521.59843 L 224.65378,521.59843 z M 234.49758,518.00466 L 240.43511,520.50467 L 242.46637,520.19217 L 244.02887,516.44215 L 243.40387,513.16089 L 239.34135,512.69214 L 235.43508,514.41089 L 234.49758,518.00466 z M 264.18522,527.69221 L 267.77898,533.00473 L 270.12274,532.69223 L 271.2165,532.22348 L 272.62275,533.47348 L 276.21652,533.31723 L 277.15403,531.91098 L 274.34151,530.19222 L 272.4665,526.59845 L 270.43524,523.16094 L 264.81022,525.97345 L 264.18522,527.69221 z M 283.71656,536.286 L 284.96656,534.41099 L 289.49783,535.34849 L 290.12284,534.87974 L 296.06036,535.50474 L 295.74786,536.75475 L 293.24785,538.161 L 289.02908,537.8485 L 283.71656,536.286 z M 288.87283,541.28602 L 290.74784,545.03604 L 293.7166,543.94228 L 294.0291,542.37977 L 292.4666,540.34851 L 288.87283,540.03601 L 288.87283,541.28602 z M 295.59161,540.19226 L 297.77912,537.37975 L 302.31039,539.72351 L 306.52916,540.81727 L 310.74793,543.47353 L 310.74793,545.34854 L 307.31042,547.0673 L 302.62289,548.0048 L 300.27913,546.59854 L 295.59161,540.19226 z M 311.68544,555.19233 L 313.24794,553.94233 L 316.52921,555.50484 L 323.87299,558.94235 L 327.15426,560.97361 L 328.71676,563.31737 L 330.59177,567.53614 L 334.49804,570.03615 L 334.18554,571.28616 L 330.43552,574.41117 L 326.373,575.81743 L 324.96675,575.19243 L 321.99798,576.91118 L 319.65422,580.0362 L 317.46671,582.84871 L 315.74795,582.69246 L 312.31044,580.19245 L 311.99794,575.81743 L 312.62294,573.47367 L 311.06043,568.00489 L 309.02917,566.28613 L 308.87292,563.78612 L 311.06043,562.84862 L 313.09169,559.87986 L 313.56044,558.94235 L 311.99794,557.22359 L 311.68544,555.19233 z \",\n    \"M 365.08234,342.9472 L 388.2557,344.07626 L 420.00963,345.26475 L 418.60872,369.98537 L 418.14175,388.52584 L 418.37523,390.18973 L 422.81144,393.9929 L 424.9128,395.18139 L 425.61327,394.94369 L 426.31372,392.80441 L 427.71463,394.70599 L 429.81599,394.70599 L 429.81599,393.2798 L 432.6178,394.70599 L 432.15084,398.74687 L 436.35356,398.98457 L 438.92189,400.17306 L 443.12462,400.88615 L 445.69295,402.78774 L 448.02779,400.64846 L 451.53007,401.36155 L 454.0984,404.92703 L 455.03233,404.92703 L 455.03233,407.30401 L 457.36718,408.0171 L 459.70203,405.64012 L 461.5699,406.35321 L 464.13823,406.35321 L 465.07218,408.9679 L 469.97536,410.86948 L 471.37627,410.15638 L 473.24415,405.87781 L 474.41156,405.87781 L 475.57899,408.0171 L 479.78172,408.73019 L 483.51747,410.15638 L 486.55277,411.10718 L 488.42065,410.15638 L 489.1211,407.54171 L 493.55731,407.54171 L 495.65868,408.49249 L 498.46049,406.35321 L 499.62792,406.35321 L 500.32837,408.0171 L 504.53109,408.0171 L 506.16549,405.87781 L 508.03337,406.35321 L 510.13473,408.9679 L 513.40351,410.86948 L 516.6723,411.82028 L 519.47412,413.12761 L 521.80896,415.14805 L 524.84426,413.72186 L 527.64608,414.91035 L 528.33194,426.45357 L 528.34653,436.5409 L 529.04699,446.28652 L 529.74745,450.3274 L 532.31578,454.60597 L 533.24971,459.83533 L 537.68592,465.54009 L 537.9194,468.86787 L 538.61987,469.58096 L 537.9194,478.3758 L 534.88411,483.60516 L 536.5185,485.74444 L 535.81804,488.35912 L 535.11759,495.96547 L 533.71668,499.29324 L 534.00598,503.01936 L 527.40119,504.83432 L 517.33018,509.5405 L 516.33959,511.55743 L 513.69802,513.57437 L 511.55174,515.08707 L 510.23095,515.92746 L 504.4525,521.47403 L 501.64583,523.65904 L 496.19758,527.0206 L 490.41913,529.54177 L 483.98029,533.07141 L 482.16421,534.58411 L 476.22066,538.28182 L 472.7536,538.95414 L 468.79123,544.66878 L 464.66377,545.00494 L 463.67318,547.02188 L 465.98456,549.03881 L 464.49867,554.75346 L 463.17788,559.45964 L 462.0222,563.49351 L 461.1967,568.19969 L 462.0222,570.72086 L 463.83828,577.94821 L 464.82887,584.33517 L 466.64495,587.1925 L 465.65436,588.7052 L 462.51749,590.72214 L 456.73904,586.68827 L 451.1257,585.51172 L 449.80491,586.01595 L 446.50294,585.34364 L 442.21038,582.15016 L 436.92723,580.97362 L 429.1676,577.44398 L 427.02132,573.41011 L 425.70053,566.68699 L 422.39856,564.67006 L 421.73817,562.31697 L 422.39856,561.64466 L 422.72876,558.11502 L 421.40797,557.44271 L 420.74758,556.43424 L 422.06837,551.89614 L 420.41738,549.54304 L 417.11541,548.19842 L 413.64834,543.66032 L 410.01618,536.76912 L 405.72362,534.07988 L 405.88872,532.06294 L 400.44047,519.28902 L 399.61497,514.91899 L 397.79889,512.90206 L 397.63379,511.38936 L 391.52515,505.84279 L 388.88357,502.6493 L 388.88357,501.47276 L 386.242,499.28775 L 379.30786,498.1112 L 371.71333,497.43889 L 368.57646,495.0858 L 363.9537,496.93466 L 360.32154,498.44736 L 358.01016,501.80891 L 357.01957,505.67471 L 352.56191,512.06167 L 350.08543,514.58284 L 347.44386,513.57437 L 345.62777,512.39782 L 343.64659,511.72551 L 339.68423,509.37242 L 339.68423,508.70011 L 337.86815,506.68317 L 332.585,504.49816 L 324.99047,496.43042 L 322.67909,491.55616 L 322.67909,483.15227 L 319.37712,476.42915 L 318.88182,473.57182 L 317.23084,472.56336 L 316.07515,470.37834 L 310.9571,468.19333 L 309.63631,466.51255 L 302.37198,458.27673 L 301.05119,454.91517 L 296.26332,452.56207 L 294.77744,448.02394 L 292.13584,444.99855 L 290.15467,444.49434 L 289.49163,439.63101 L 297.66367,440.34413 L 327.31615,443.19648 L 356.96871,444.86037 L 359.30356,420.13975 L 363.27277,362.37936 L 364.90719,342.88781 L 366.3081,342.91754 M 467.38967,586.18345 L 466.81183,578.788 L 464.00514,571.30851 L 463.42729,563.99709 L 464.99573,555.42509 L 468.38027,548.28176 L 471.92989,542.65112 L 475.14933,538.95339 L 475.80972,539.20552 L 470.9393,546.09673 L 466.48163,552.90391 L 464.41788,559.79513 L 464.08769,565.17365 L 464.99573,571.56063 L 467.63732,579.04012 L 468.13261,584.41863 L 468.29771,585.93134 L 467.38967,586.18345 z \",\n    \"M 140.74058,399.1133 L 144.96457,398.27159 L 146.48222,396.01346 L 147.06593,393.16108 L 143.33019,392.56684 L 142.86321,391.73489 L 143.33019,389.95216 L 143.44692,383.89086 L 145.54828,383.17775 L 148.46685,380.32538 L 149.05056,375.21486 L 150.56821,371.4117 L 152.55282,369.39125 L 156.0551,367.60852 L 157.68948,366.18234 L 157.80623,363.80536 L 156.75555,363.21111 L 155.93835,362.14147 L 154.65419,356.08016 L 151.85237,350.96965 L 152.44317,347.57226 L 149.86775,344.19525 L 135.04148,320.54427 L 115.19528,290.35661 L 91.963567,255.17727 L 79.318752,235.85757 L 80.989783,229.03046 L 88.111072,202.05171 L 96.399776,169.3682 L 82.624178,165.56503 L 68.848582,161.99955 L 56.006928,157.72098 L 48.301935,155.58169 L 36.627704,152.49162 L 29.426941,149.98419 L 27.813217,154.89608 L 27.648119,162.62767 L 22.364968,174.89736 L 19.228097,177.5866 L 18.8979,178.76315 L 17.081817,179.60354 L 15.595931,183.97356 L 14.770438,187.33512 L 17.577112,191.70515 L 19.228097,196.07518 L 20.383786,199.77289 L 20.053589,206.49601 L 18.237506,209.68949 L 17.577112,215.74029 L 16.586521,219.60608 L 18.402605,223.63995 L 21.209279,228.34614 L 23.520657,233.38847 L 24.841445,237.59042 L 24.511248,240.95198 L 24.181051,241.45621 L 24.181051,243.64123 L 29.959497,250.19627 L 29.464202,252.71743 L 28.803808,255.07053 L 28.143414,257.08746 L 28.308513,265.65943 L 30.454793,269.52523 L 32.435974,272.21447 L 35.242648,272.71871 L 36.233239,275.57603 L 35.07755,279.27375 L 32.93127,280.95453 L 31.775581,280.95453 L 30.950088,284.9884 L 31.445384,288.0138 L 34.747353,292.5519 L 36.398338,298.09847 L 37.884224,302.97273 L 39.205012,306.16621 L 42.672079,312.21702 L 44.157966,314.90627 L 44.653261,317.93167 L 46.304246,318.94014 L 46.304246,321.4613 L 45.478753,323.47824 L 43.66267,330.87367 L 43.167375,332.8906 L 45.643852,335.74793 L 49.936412,336.25216 L 54.559169,338.10102 L 58.521532,340.28603 L 61.493305,340.28603 L 64.465077,343.47951 L 67.106653,348.52185 L 68.262342,350.87494 L 72.224705,353.05995 L 77.177659,353.90034 L 78.663546,356.08536 L 79.32394,359.44692 L 77.838053,360.11923 L 78.16825,361.12769 L 81.470222,361.96808 L 84.276896,362.13616 L 87.248668,367.01042 L 91.211035,371.38045 L 92.036527,373.73354 L 94.678102,378.10356 L 95.008299,381.46512 L 95.008299,391.21364 L 95.503595,393.0625 L 105.7397,394.5752 L 125.88171,397.43253 L 140.74058,399.1133 z M 50.26694,346.75563 L 51.587732,348.35237 L 51.422633,349.697 L 48.120652,349.61296 L 47.542806,348.35237 L 46.88241,346.83966 L 50.26694,346.75563 z M 52.248128,346.75563 L 53.48637,346.08332 L 57.118549,348.26833 L 60.255432,349.52892 L 59.347387,350.20124 L 54.724613,349.94912 L 53.073623,348.26833 L 52.248128,346.75563 z M 73.380807,367.34524 L 75.19689,369.78238 L 76.022393,370.79086 L 77.590834,371.37912 L 78.168673,369.86642 L 77.178082,368.01756 L 74.453952,365.91658 L 73.380807,366.08465 L 73.380807,367.34524 z M 71.89491,376.33744 L 73.711004,379.61497 L 74.949248,381.63192 L 73.463351,381.88403 L 72.142563,380.62344 C 72.142563,380.62344 71.399615,379.11074 71.399615,378.69054 C 71.399615,378.27035 71.399615,376.42148 71.399615,376.42148 L 71.89491,376.33744 z \",\n    \"M 141.11208,399.22238 L 138.4292,401.4664 L 138.099,402.9791 L 138.5943,403.98756 L 157.91082,415.08071 L 170.2932,422.98037 L 185.31716,431.8885 L 202.4874,442.30933 L 215.03489,444.8305 L 242.33612,448.47703 L 244.42909,434.63935 L 248.26156,406.64864 L 255.37454,351.33455 L 259.72234,319.30647 L 233.45531,315.31482 L 205.67064,310.56085 L 171.53056,303.99238 L 168.54652,322.80241 L 168.07955,323.2778 L 166.32842,326.01134 L 163.76009,325.89248 L 162.47592,323.04011 L 159.67411,322.68356 L 158.74017,321.49507 L 157.80623,321.49507 L 156.87229,322.08932 L 154.88767,323.15896 L 154.77093,330.40875 L 154.53744,332.19149 L 153.95374,345.26489 L 152.43609,347.52302 L 151.85237,350.96965 L 154.65419,356.08016 L 155.93835,362.14147 L 156.75555,363.21111 L 157.80623,363.80536 L 157.68948,366.18234 L 156.0551,367.60852 L 152.55282,369.39125 L 150.56821,371.4117 L 149.05056,375.21486 L 148.46685,380.32538 L 145.54828,383.17775 L 143.44692,383.89086 L 143.33019,389.95216 L 142.86321,391.73489 L 143.33019,392.56684 L 147.06593,393.16108 L 146.48222,396.01346 L 144.96457,398.27159 L 141.11208,399.22238 z \",\n    \"M 144.08485,180.96023 L 165.51122,185.65054 L 175.43432,187.67098 L 184.89044,189.57255 L 193.12078,191.77126 L 191.89498,197.53545 L 188.27597,215.71936 L 184.42347,236.99336 L 182.43886,246.26359 L 180.22075,260.40663 L 176.83522,277.63975 L 173.56644,293.44668 L 171.55619,304.36486 L 168.54652,322.80241 L 168.07955,323.2778 L 166.32842,326.01134 L 163.76009,325.89248 L 162.47592,323.04011 L 159.67411,322.68356 L 158.74017,321.49507 L 157.80623,321.49507 L 156.87229,322.08932 L 154.88767,323.15896 L 154.77093,330.40875 L 154.53744,332.19149 L 153.95374,345.26489 L 152.43963,347.54764 L 149.86775,344.19525 L 135.04148,320.54427 L 115.19528,290.35661 L 91.963567,255.17727 L 79.318752,235.85757 L 80.989783,229.03046 L 88.111072,202.05171 L 96.166292,169.45944 L 130.48854,177.92533 L 144.49761,181.0154\",\n    \"M 259.6056,319.59339 L 233.45531,315.31482 L 205.67064,310.56085 L 171.45228,304.13508 L 173.56644,293.44668 L 176.83522,277.63975 L 180.22075,260.40663 L 182.43886,246.26359 L 184.42347,236.99336 L 188.27597,215.71936 L 191.89498,197.53545 L 193.03322,191.74155 L 206.02081,194.08882 L 218.27875,196.22811 L 228.78555,198.12969 L 237.30774,199.55589 L 242.21095,200.38777 L 240.53069,211.44019 L 238.82546,223.80098 L 245.48808,224.7662 L 262.73518,227.14318 L 272.10412,228.36648 L 268.94498,251.37398 L 265.6762,274.66841 L 261.84373,303.76606 L 260.30605,315.31482 L 259.6056,319.59339 z \",\n    \"M 384.05299,331.95365 L 388.2557,263.49654 L 389.8901,240.2021 L 355.80134,237.34972 L 330.81813,235.21041 L 292.76047,230.93187 L 271.63008,228.31722 L 268.94498,251.37398 L 265.6762,274.66841 L 261.84373,303.76606 L 260.30605,315.31482 L 259.72234,319.35569 L 294.86179,323.63426 L 332.58567,328.23704 L 366.04543,330.52751 L 372.84567,331.2406 L 384.5199,331.83485\",\n    \"M 290.31977,444.66242 L 289.49163,439.63101 L 297.66367,440.34413 L 327.31615,443.19648 L 356.96871,444.86037 L 359.30356,420.13975 L 363.27277,362.37936 L 364.90719,342.88781 L 366.3081,342.91754 L 366.29351,330.73549 L 332.58567,328.23704 L 294.86179,323.63426 L 259.66398,319.35569 L 255.37454,351.33455 L 248.26156,406.64864 L 244.42909,434.63935 L 242.33612,448.47703 L 258.12559,450.54515 L 259.44637,440.12432 L 276.45152,442.81356 L 290.31977,444.66242 z \",\n    \"M 144.38087,180.54003 L 148.93381,161.76187 L 153.37002,143.34026 L 154.77093,138.94284 L 157.33926,132.76269 L 156.0551,130.38571 L 153.48676,130.50455 L 152.66957,129.43491 L 153.13654,128.24642 L 153.48676,125.0375 L 158.03971,119.33273 L 159.90759,118.85734 L 161.07501,117.66885 L 161.65873,114.34107 L 162.59266,113.62798 L 166.5619,107.56668 L 170.53114,103.05041 L 170.76463,99.128389 L 167.26235,96.394856 L 166.19165,92.03947 L 151.85237,88.313121 L 136.44238,84.628799 L 120.68217,84.747642 L 120.21521,83.321459 L 114.61157,85.460744 L 110.05862,84.866496 L 107.60703,83.202605 L 106.32286,83.915707 L 101.53644,83.678 L 99.785303,82.251817 L 94.415149,80.112532 L 93.597952,80.231386 L 89.161743,78.686338 L 87.177124,80.587926 L 80.873036,80.231386 L 74.802439,75.952816 L 75.50289,75.12087 L 75.736374,67.039124 L 73.401527,62.998262 L 69.198802,62.404014 L 68.498351,59.789335 L 66.094359,59.304248 L 60.172517,61.44476 L 57.861139,68.167876 L 54.559169,78.588708 L 51.2572,85.311824 L 46.139147,99.934604 L 39.535209,114.05315 L 31.280285,127.16323 L 29.299104,130.18863 L 28.473611,139.09676 L 27.152823,145.31564 L 29.426941,149.98419 L 36.627704,152.49162 L 48.301935,155.58169 L 56.006928,157.72098 L 68.848582,161.99955 L 82.624178,165.56503 L 96.399776,169.60589 M 144.08485,180.96023 L 96.166292,169.45944 L 130.48854,177.92533 L 144.49761,181.0154\",\n    \"M 482.58353,129.91009 L 481.88308,121.11525 L 480.0152,113.50891 L 478.14732,99.484714 L 477.68036,89.263683 L 475.81248,85.698205 L 474.17808,80.468846 L 474.17808,69.772421 L 474.87853,65.731548 L 472.88209,60.014242 L 442.87077,59.427825 L 423.88445,58.755513 L 396.8083,57.410889 L 371.33142,55.452236 L 370.0439,70.247815 L 368.64299,85.935913 L 366.33647,111.87386 L 365.67607,124.49947 L 423.04492,128.24621 L 482.58353,129.91009 z \",\n    \"M 484.10703,208.42015 L 483.13305,206.29529 L 481.4161,203.35887 L 483.28398,198.8426 L 484.6849,192.90014 L 481.88308,190.76086 L 481.4161,187.90848 L 482.35005,185.29379 L 484.21793,185.29379 L 484.6849,178.16284 L 484.45141,146.54897 L 483.98444,143.4589 L 479.78172,139.89342 L 478.61429,137.99183 L 478.61429,136.32794 L 480.71565,134.66406 L 482.11657,133.23787 L 482.4668,129.91009 L 423.04492,128.24621 L 365.67608,124.20534 L 364.89307,129.69427 L 363.24575,146.19243 L 361.87193,164.85174 L 360.23755,191.5928 L 376.1145,192.66245 L 396.66115,193.85093 L 414.87297,195.03943 L 439.15538,196.22791 L 450.12916,195.75252 L 452.23052,198.1295 L 457.1337,201.21959 L 458.30112,202.17037 L 462.73733,200.74418 L 466.70658,200.26879 L 469.50839,200.03109 L 471.37627,201.45728 L 476.51293,203.12117 L 479.54822,204.78505 L 480.0152,206.44894 L 480.94914,208.58823 L 482.81702,208.58823 L 484.10703,208.42015 z \",\n    \"M 496.12564,252.80011 L 497.52656,255.41479 L 497.29307,257.79177 L 499.8614,261.83265 L 503.13018,266.11122 L 496.82609,266.11122 L 451.76325,265.63581 L 410.43676,264.20963 L 388.13897,263.37769 L 389.8901,240.2021 L 355.80134,237.34972 L 360.23755,191.5928 L 376.1145,192.66245 L 396.66115,193.85093 L 414.87297,195.03943 L 439.15538,196.22791 L 450.12916,195.75252 L 452.23052,198.1295 L 457.1337,201.21959 L 458.30112,202.17037 L 462.73733,200.74418 L 466.70658,200.26879 L 469.50839,200.03109 L 471.37627,201.45728 L 476.51293,203.12117 L 479.54822,204.78505 L 480.0152,206.44894 L 480.94914,208.58823 L 482.81702,208.58823 L 484.45141,208.46938 L 485.61883,214.05529 L 488.42065,221.89933 L 489.35459,226.891 L 491.68943,230.69417 L 492.38988,236.16123 L 494.02428,240.4398 L 494.25776,247.33306 L 496.23653,253.05224\",\n    \"M 580.12177,205.73586 L 580.18014,207.63744 L 582.51499,208.35053 L 583.44892,209.53902 L 583.91589,211.44061 L 587.88513,215.00608 L 588.58559,217.38307 L 587.88513,220.94855 L 586.01725,224.75171 L 585.3168,227.36639 L 582.98196,229.26798 L 581.11408,229.98108 L 575.74393,231.40726 L 575.04347,233.30885 L 574.34302,235.44814 L 575.04347,236.87433 L 576.91135,238.53822 L 576.67787,242.81678 L 574.80999,244.48067 L 574.10954,246.14456 L 574.10954,248.99694 L 572.24166,249.47233 L 570.60726,250.66083 L 570.37378,252.08702 L 570.60726,254.22631 L 568.85613,256.06846 L 565.4706,252.56242 L 564.30317,250.18543 L 556.3647,250.89852 L 546.32485,251.37392 L 520.40805,252.32472 L 506.63246,252.56242 L 497.05959,252.80011 L 495.9476,252.92617 L 494.25776,247.33306 L 494.02428,240.4398 L 492.38988,236.16123 L 491.68943,230.69417 L 489.35459,226.891 L 488.42065,221.89933 L 485.61883,214.05529 L 484.45141,208.46938 L 483.0505,206.21125 L 481.4161,203.35887 L 483.28398,198.8426 L 484.6849,192.90014 L 481.88308,190.76086 L 481.4161,187.90848 L 482.35005,185.29379 L 484.10119,185.29379 L 495.89216,185.29379 L 546.55834,184.5807 L 565.00364,183.86761 L 569.20636,183.74877 L 569.90681,187.19538 L 572.24166,188.85927 L 572.47514,190.28546 L 570.37378,193.85093 L 570.60726,197.17871 L 573.1756,201.21959 L 575.74393,202.40807 L 578.77923,202.88347 L 580.12177,205.73586 z \",\n    \"M 639.20393,481.84625 L 638.01716,483.15227 L 632.73401,483.15227 L 631.24813,482.31188 L 629.10185,481.97572 L 622.16771,483.99266 L 620.35163,483.15227 L 617.71005,487.52229 L 616.58406,488.3312 L 615.43633,485.74444 L 614.2689,481.70357 L 610.76664,478.3758 L 611.93406,470.53175 L 611.23361,469.58096 L 609.36573,469.81866 L 600.96028,470.53175 L 576.2109,471.24485 L 575.74393,469.58096 L 576.44438,461.26152 L 579.94666,454.84366 L 585.3168,445.33573 L 584.38287,443.19645 L 585.55029,443.19645 L 586.25075,439.86868 L 583.91589,437.96709 L 584.14938,436.0655 L 582.04802,431.31154 L 581.75616,425.75534 L 583.15706,422.99209 L 582.74847,418.47583 L 581.34756,415.38574 L 582.74847,413.95956 L 581.34756,411.82028 L 581.81454,409.91869 L 582.74847,403.50083 L 585.78377,400.64846 L 585.08332,398.50917 L 588.81908,393.0421 L 591.62089,392.09132 L 591.62089,389.47664 L 590.92044,388.05044 L 593.72225,382.58339 L 596.52407,381.39489 L 596.63379,377.84737 L 605.49374,377.76685 L 630.09345,375.74991 L 635.69855,375.51222 L 635.7068,382.13688 L 635.8719,399.44893 L 635.04641,431.71994 L 634.88131,446.34274 L 637.68799,465.83981 L 639.20393,481.84625 z \",\n    \"M 632.23973,310.19942 L 632.07463,306.16555 L 632.56993,301.45935 L 634.88131,298.43395 L 636.6974,294.40007 L 639.33898,290.03004 L 638.84368,283.97923 L 637.0276,281.12189 L 636.6974,277.76034 L 637.52289,272.04567 L 637.0276,264.81831 L 635.7068,248.17858 L 634.38601,232.21115 L 633.3949,220.02589 L 636.53128,220.95071 L 638.01716,221.95917 L 639.17285,221.62302 L 641.31913,219.60608 L 644.20888,217.92491 L 649.40999,217.75643 L 671.86343,215.40333 L 678.13717,214.73102 L 678.30227,215.90756 L 679.78816,231.20268 L 681.60425,245.48932 L 684.24582,269.86066 L 684.74112,275.7434 L 684.24582,278.09649 L 685.73171,279.60919 L 686.06192,281.62613 L 683.25523,283.64307 L 679.29287,285.49193 L 676.48618,285.82809 L 675.99089,290.53428 L 671.20302,294.56815 L 668.23125,298.26587 L 668.56145,300.61896 L 667.73595,302.80398 L 662.94809,302.80398 L 661.7924,301.1232 L 660.63671,301.96359 L 657.66493,303.64438 L 657.83004,307.17401 L 655.68375,307.67825 L 654.85825,306.5017 L 652.87707,304.82092 L 649.90529,306.33362 L 648.08921,309.69518 L 646.27312,308.85479 L 644.78724,306.83786 L 641.15506,307.34209 L 635.2115,308.35056 L 632.23973,310.19942 z \",\n    \"M 632.07463,310.03134 L 632.07463,306.16555 L 632.56993,301.45935 L 634.88131,298.43395 L 636.6974,294.40007 L 639.33898,290.03004 L 638.84368,283.97923 L 637.0276,281.12189 L 636.6974,277.76034 L 637.52289,272.04567 L 637.0276,264.81831 L 635.7068,248.17858 L 634.38601,232.21115 L 633.56001,220.10992 L 632.23872,219.26993 L 631.41322,216.58068 L 630.09244,212.71489 L 628.44145,210.86603 L 626.95557,208.17679 L 626.71703,202.46993 L 616.60376,203.83427 L 588.81909,205.617 L 579.94666,205.17133 L 580.18014,207.63744 L 582.51499,208.35053 L 583.44892,209.53902 L 583.91589,211.44061 L 587.88513,215.00608 L 588.58559,217.38307 L 587.88513,220.94855 L 586.01725,224.75171 L 585.3168,227.36639 L 582.98196,229.26798 L 581.11408,229.98108 L 575.74393,231.40726 L 575.04347,233.30885 L 574.34302,235.44814 L 575.04347,236.87433 L 576.91135,238.53822 L 576.67787,242.81678 L 574.80999,244.48067 L 574.10954,246.14456 L 574.10954,248.99694 L 572.24166,249.47233 L 570.60726,250.66083 L 570.37378,252.08702 L 570.60726,254.22631 L 568.85613,255.59306 L 567.80545,258.50488 L 568.27242,262.30804 L 570.60726,269.91439 L 578.07878,277.75843 L 583.68241,281.56161 L 583.44892,286.07787 L 584.38287,287.50407 L 590.92044,287.97946 L 593.72225,289.40566 L 593.0218,293.20882 L 590.68696,299.38898 L 589.98649,302.71676 L 592.32134,306.75762 L 598.85891,312.22469 L 603.52862,312.93778 L 605.62997,318.16715 L 607.73133,321.49492 L 606.7974,324.58499 L 608.43179,328.86356 L 610.29967,331.00285 L 613.32836,330.65102 L 613.91377,328.51994 L 616.22516,326.67109 L 618.37144,325.99877 L 621.17811,327.3434 L 624.81029,328.68802 L 625.96598,328.35186 L 626.13108,325.99877 L 624.81029,323.47759 L 625.14049,321.1245 L 627.12167,319.6118 L 629.76325,318.93949 L 631.41424,318.26718 L 630.58875,316.41831 L 629.92835,314.40138 L 631.08404,313.56099 L 632.07463,310.03134 z \",\n    \"M 482.35005,129.91009 L 481.88308,121.11525 L 480.0152,113.50891 L 478.14732,99.484714 L 477.68036,89.263683 L 475.81248,85.698205 L 474.17808,80.468846 L 474.17808,69.772421 L 474.87853,65.731548 L 473.01887,60.063466 L 503.79211,60.100136 L 504.1223,51.528162 L 504.7827,51.360084 L 507.09408,51.864318 L 509.07526,52.704708 L 509.90075,58.419357 L 511.38664,64.806318 L 513.03762,66.487097 L 517.99058,66.487097 L 518.32077,67.999799 L 524.75961,68.335954 L 524.75961,70.520967 L 529.71257,70.520967 L 530.04276,69.176344 L 531.19845,67.999799 L 533.50983,67.327487 L 534.83062,68.335954 L 537.80239,68.335954 L 541.76476,71.025201 L 547.21301,73.54637 L 549.68948,74.050604 L 550.18478,73.042136 L 551.67066,72.537902 L 552.16596,75.563305 L 554.80753,76.907928 L 555.30283,76.403695 L 556.62362,76.571773 L 556.62362,78.756786 L 559.26519,79.765253 L 562.40206,79.765253 L 564.05305,78.924863 L 567.35502,75.563305 L 569.99659,75.059071 L 570.82209,76.907928 L 571.31738,78.252552 L 572.30797,78.252552 L 573.29856,77.412162 L 582.37898,77.076006 L 584.19506,80.269487 L 584.85546,80.269487 L 585.58425,79.142165 L 590.11857,78.756786 L 589.49346,81.126733 L 585.47097,83.036786 L 576.02857,87.25913 L 571.15228,89.345695 L 568.01541,92.034941 L 565.53894,95.732656 L 563.22756,99.766526 L 561.41147,100.60692 L 556.78872,105.81733 L 555.46793,105.98541 L 552.00086,109.17889 L 552.70347,109.74365 L 549.82713,112.55812 L 549.59365,115.4105 L 549.59365,124.20534 L 548.42622,125.86923 L 543.05607,129.91009 L 540.72123,136.09025 L 541.18819,136.32794 L 543.75652,138.46723 L 544.45698,141.79501 L 542.5891,145.12278 L 542.5891,149.16365 L 543.05607,156.0569 L 546.09137,159.14699 L 549.59365,159.14699 L 551.46153,162.47476 L 554.96379,162.95015 L 558.93303,168.89261 L 566.17105,173.17118 L 568.27242,176.02356 L 569.20636,183.86761 L 565.00364,183.86761 L 546.55834,184.5807 L 495.89216,185.29379 L 484.10119,185.29379 L 484.6849,178.16284 L 484.45141,146.54897 L 483.98444,143.4589 L 479.78172,139.89342 L 478.61429,137.99183 L 478.61429,136.32794 L 480.71565,134.66406 L 482.11657,133.23787 L 482.35005,129.91009 z \",\n    \"M 626.6436,202.64577 L 626.79047,198.26019 L 625.13948,193.55401 L 624.47909,187.16705 L 623.3234,184.64588 L 624.31399,181.4524 L 625.13948,178.42699 L 626.62537,175.73775 L 625.96497,172.20811 L 625.30458,168.5104 L 625.79988,166.66154 L 627.78106,164.14037 L 627.94616,161.28305 L 627.12066,159.93842 L 627.78106,157.24918 L 628.27635,153.88762 L 631.08303,148.00489 L 634.0548,140.94562 L 634.2199,138.59253 L 633.8897,137.58406 L 633.06421,138.08829 L 628.77165,144.64333 L 625.96497,148.84528 L 623.98379,150.69414 L 623.1583,153.04723 L 621.67241,153.88762 L 620.51673,155.90455 L 619.03084,155.5684 L 618.86574,153.71954 L 620.18653,151.19837 L 622.33281,146.32411 L 624.14889,144.64333 L 625.27363,142.26081 L 623.6083,141.31962 L 622.20739,139.89342 L 620.57299,129.197 L 616.83724,128.00851 L 615.43633,125.63153 L 602.59467,122.77914 L 600.02634,121.59066 L 591.62089,119.21367 L 583.21544,118.02518 L 578.9573,112.40581 L 578.41662,113.71699 L 577.26093,113.54892 L 576.60053,112.37237 L 573.79386,111.53198 L 572.63817,111.70006 L 570.82209,112.70853 L 569.8315,112.03621 L 570.49189,110.01928 L 572.47307,106.8258 L 573.62876,105.64925 L 571.64758,104.13655 L 569.5013,104.97694 L 566.52953,106.99388 L 558.935,110.35543 L 555.96322,111.02775 L 552.99145,110.52351 L 551.98885,109.6104 L 549.82713,112.55812 L 549.59365,115.4105 L 549.59365,124.20534 L 548.42622,125.86923 L 543.05607,129.91009 L 540.72123,136.09025 L 541.18819,136.32794 L 543.75652,138.46723 L 544.45698,141.79501 L 542.5891,145.12278 L 542.5891,149.16365 L 543.05607,156.0569 L 546.09137,159.14699 L 549.59365,159.14699 L 551.46153,162.47476 L 554.96379,162.95015 L 558.93303,168.89261 L 566.17105,173.17118 L 568.27242,176.02356 L 569.20636,183.74877 L 569.90681,187.19538 L 572.24166,188.85927 L 572.47514,190.28546 L 570.37378,193.85093 L 570.60726,197.17871 L 573.1756,201.21959 L 575.74393,202.40807 L 578.77923,202.88347 L 580.03422,205.49817 L 589.40281,205.49815 L 616.60376,203.83427 L 626.6436,202.64577 z \",\n    \"M 568.73938,255.89021 L 565.4706,252.56242 L 564.30317,250.18543 L 556.3647,250.89852 L 546.32485,251.37392 L 520.40805,252.32472 L 506.63246,252.56242 L 498.57727,252.68126 L 496.24239,252.80011 L 497.52656,255.41479 L 497.29307,257.79177 L 499.8614,261.83265 L 503.01343,266.11122 L 506.16549,268.96359 L 508.50034,269.20129 L 509.90124,270.15209 L 509.90124,273.24216 L 508.03337,274.90605 L 507.56639,277.28304 L 509.66775,280.84852 L 512.23609,283.93859 L 514.80442,285.84018 L 516.20533,297.96278 L 515.50487,334.68718 L 515.73836,339.55999 L 516.20533,346.69094 L 540.02077,346.21554 L 563.83621,345.50245 L 585.08332,344.55165 L 596.29058,344.07626 L 598.15846,347.16634 L 597.69149,349.54332 L 594.4227,352.3957 L 593.72225,355.48577 L 600.02634,355.96118 L 605.163,355.24808 L 607.26436,348.59252 L 607.11843,342.73921 L 610.06619,341.22388 L 611.46709,339.55999 L 613.56845,338.3715 L 613.80194,335.04372 L 614.73588,333.14213 L 613.33497,330.61659 L 610.29967,331.00285 L 608.43179,328.86356 L 606.7974,324.58499 L 607.73133,321.49492 L 605.62997,318.16715 L 603.52862,312.93778 L 598.85891,312.22469 L 592.32134,306.75762 L 589.98649,302.71676 L 590.68696,299.38898 L 593.0218,293.20882 L 593.72225,289.40566 L 590.92044,287.97946 L 584.38287,287.50407 L 583.44892,286.07787 L 583.68241,281.56161 L 578.07878,277.75843 L 570.60726,269.91439 L 568.27242,262.30804 L 567.80545,258.50488 L 568.73938,255.89021 z \",\n    \"M 604.99844,354.98628 L 600.02634,355.96118 L 593.72225,355.48577 L 594.4227,352.3957 L 597.69149,349.54332 L 598.15846,347.16634 L 596.29058,344.07626 L 585.08332,344.55165 L 563.83621,345.50245 L 540.02077,346.21554 L 516.20533,346.69094 L 517.83972,353.82189 L 517.83971,362.37904 L 519.24063,373.78867 L 519.47412,413.12761 L 521.80896,415.14805 L 524.84426,413.72186 L 527.64608,414.91035 L 528.31735,426.58728 L 550.99455,426.55757 L 570.60726,425.60677 L 581.63941,425.75534 L 583.15706,422.99209 L 582.74847,418.47583 L 581.34756,415.38574 L 582.74847,413.95956 L 581.34756,411.82028 L 581.81454,409.91869 L 582.74847,403.50083 L 585.78377,400.64846 L 585.08332,398.50917 L 588.81908,393.0421 L 591.62089,392.09132 L 591.62089,389.47664 L 590.92044,388.05044 L 593.72225,382.58339 L 596.52407,381.39489 L 596.22104,377.59524 L 598.72469,376.42223 L 599.71528,371.54796 L 598.22939,367.85023 L 602.35687,365.49714 L 602.68706,362.80789 L 604.06449,358.25292 L 604.99844,354.98628 z \",\n    \"M 383.76113,331.71594 L 372.84567,331.2406 L 366.27891,330.73549 L 366.54158,330.94347 L 365.98708,342.94722 L 388.2557,344.07626 L 420.00963,345.26475 L 418.60872,369.98537 L 418.14175,388.52584 L 418.37523,390.18973 L 422.81144,393.9929 L 424.9128,395.18139 L 425.61327,394.94369 L 426.31372,392.80441 L 427.71463,394.70599 L 429.81599,394.70599 L 429.81599,393.2798 L 432.6178,394.70599 L 432.15084,398.74687 L 436.35356,398.98457 L 438.92189,400.17306 L 443.12462,400.88615 L 445.69295,402.78774 L 448.02779,400.64846 L 451.53007,401.36155 L 454.0984,404.92703 L 455.03233,404.92703 L 455.03233,407.30401 L 457.36718,408.0171 L 459.70203,405.64012 L 461.5699,406.35321 L 464.13823,406.35321 L 465.07218,408.9679 L 469.97536,410.86948 L 471.37627,410.15638 L 473.24415,405.87781 L 474.41156,405.87781 L 475.57899,408.0171 L 479.78172,408.73019 L 483.51747,410.15638 L 486.55277,411.10718 L 488.42065,410.15638 L 489.1211,407.54171 L 493.55731,407.54171 L 495.65868,408.49249 L 498.46049,406.35321 L 499.62792,406.35321 L 500.32837,408.0171 L 504.53109,408.0171 L 506.16549,405.87781 L 508.03337,406.35321 L 510.13473,408.9679 L 513.40351,410.86948 L 516.6723,411.82028 L 519.47412,413.48417 L 519.24063,373.78867 L 517.83971,362.37904 L 517.83972,353.82189 L 516.20533,346.69094 L 515.73836,339.55999 L 515.50487,334.92488 L 501.9627,335.75681 L 454.56566,335.28143 L 408.56892,333.14212 L 383.76113,331.71594 z \",\n    \"M 515.50487,335.04372 L 501.9627,335.75681 L 454.56566,335.28143 L 408.56892,333.14212 L 383.90706,331.83479 L 388.13897,263.37769 L 410.43676,264.20963 L 451.76325,265.63581 L 496.82609,266.11122 L 503.01343,266.11122 L 506.16549,268.96359 L 508.50034,269.20129 L 509.90124,270.15209 L 509.90124,273.24216 L 508.03337,274.90605 L 507.56639,277.28304 L 509.66775,280.84852 L 512.23609,283.93859 L 514.80442,285.84018 L 516.20533,297.96278 L 515.50487,335.04372 z \",\n    \"M 616.71945,488.11058 L 615.43633,485.74444 L 614.2689,481.70357 L 610.76664,478.3758 L 611.93406,470.53175 L 611.23361,469.58096 L 609.36573,469.81866 L 600.96028,470.53175 L 576.2109,471.24485 L 575.74393,469.58096 L 576.44438,461.26152 L 579.94666,454.84366 L 585.3168,445.33573 L 584.38287,443.19645 L 585.55029,443.19645 L 586.25075,439.86868 L 583.91589,437.96709 L 584.14938,436.0655 L 582.04802,431.31154 L 581.69779,425.60677 L 570.60726,425.60677 L 550.99455,426.55757 L 528.31735,426.58728 L 528.34653,436.5409 L 529.04699,446.28652 L 529.74745,450.3274 L 532.31578,454.60597 L 533.24971,459.83533 L 537.68592,465.54009 L 537.9194,468.86787 L 538.61987,469.58096 L 537.9194,478.3758 L 534.88411,483.60516 L 536.5185,485.74444 L 535.81804,488.35912 L 535.11759,495.96547 L 533.71668,499.29324 L 533.84174,503.05325 L 538.62788,501.47276 L 546.88281,501.1366 L 557.44911,504.83432 L 564.05305,506.01086 L 567.85031,504.49816 L 571.15228,505.67471 L 574.45425,506.68317 L 575.27974,504.49816 L 571.97778,503.32162 L 569.3362,503.82585 L 566.52953,502.14507 C 566.52953,502.14507 566.69462,500.80045 567.35502,500.63237 C 568.01541,500.46429 570.49189,499.6239 570.49189,499.6239 L 572.30797,501.1366 L 574.12406,500.12814 L 577.42603,500.80045 L 578.91191,503.32162 L 579.24211,505.67471 L 583.86487,506.01086 L 585.68095,507.85972 L 584.85546,509.5405 L 583.53467,510.38089 L 585.18565,512.06167 L 593.77077,515.75938 L 597.40294,514.41476 L 598.39353,511.89359 L 601.03511,511.22128 L 602.85119,509.70858 L 604.17198,510.71704 L 604.99747,513.74245 L 602.68609,514.58284 L 603.34648,515.25515 L 606.81355,513.91053 L 609.12493,510.38089 L 609.95042,509.87666 L 607.80414,509.5405 L 608.62964,507.85972 L 608.46454,506.34702 L 610.61082,505.84279 L 611.76651,504.49816 L 612.4269,505.33855 C 612.4269,505.33855 612.2618,508.53203 613.08729,508.53203 C 613.91279,508.53203 617.37985,509.20434 617.37985,509.20434 L 621.50732,511.22128 L 622.49791,512.73398 L 625.46968,512.73398 L 626.62537,513.74245 L 628.93675,510.54897 L 628.93675,509.03627 L 627.61596,509.03627 L 624.14889,506.17894 L 618.20535,505.33855 L 614.90338,502.98546 L 616.05907,500.12814 L 618.37045,500.46429 L 618.53554,499.79198 L 616.71946,498.78351 L 616.71946,498.27928 L 620.02143,498.27928 L 621.83751,495.0858 L 620.51673,493.06886 L 620.18653,490.21154 L 618.70064,490.37962 L 616.71946,492.56463 L 616.05907,495.25388 L 612.9222,494.58156 L 611.93161,492.73271 L 613.74769,490.71577 L 615.81141,488.86693 L 616.71945,488.11058 z \",\n    \"M 738.7284,305.32516 L 740.70958,309.02287 L 742.03037,310.36749 L 745.00215,311.2079 L 747.64373,310.53557 L 750.12022,308.18248 C 750.12022,308.18248 751.9363,309.69518 752.59669,309.52711 C 753.25709,309.35903 757.05436,308.51864 757.05436,308.51864 L 758.87045,303.64438 L 761.51202,304.65285 L 764.814,302.13167 L 766.29989,302.46782 L 768.44617,300.45089 L 768.61127,297.59356 L 767.78577,296.24894 L 772.90384,284.9877 L 775.05012,278.09649 L 775.38031,273.55838 L 777.1964,273.3903 L 778.84739,276.24763 L 780.16818,277.08802 L 782.80976,277.08802 L 783.96545,271.37336 L 784.29564,268.17988 L 787.76272,267.84373 L 788.25802,265.49063 L 791.39489,262.96946 L 792.05529,261.28868 L 793.70628,258.43134 L 794.20157,256.24633 L 794.36667,250.69975 L 798.98943,252.5486 L 804.7679,255.7421 L 805.59338,250.44764 L 809.88595,252.5486 L 809.88595,255.57402 L 815.49931,256.91864 L 817.48049,258.26326 L 818.47108,256.24633 L 820.78247,257.92711 L 819.29657,261.28868 L 818.96637,264.146 L 817.15029,266.83525 L 817.15029,269.02027 L 817.81068,270.86913 L 822.98233,272.27864 L 824.90863,273.89525 L 830.19178,274.23141 L 832.83336,276.5845 L 836.13533,277.25681 L 837.45611,278.60143 L 836.96082,283.30762 L 837.95141,284.31608 L 838.11651,286.66917 L 839.43729,288.85419 L 839.2722,290.70305 L 835.97023,289.5265 L 835.97023,290.53497 L 837.95141,292.21575 L 837.95141,293.39229 L 839.43729,294.56884 L 840.75808,296.24962 L 840.92318,298.60271 L 838.6118,300.11541 L 838.942,300.61964 L 841.58358,300.11541 L 844.88554,299.4431 L 846.04123,299.27502 L 850.20356,306.58097 L 845.21707,308.35056 L 833.49506,311.37597 L 813.92151,315.35219 L 792.88078,319.27565 L 775.38031,321.96489 L 759.22415,323.98183 L 751.9363,325.32646 L 747.32856,324.68385 L 745.16725,324.65414 L 742.69078,326.67109 L 734.60093,326.83916 L 722.3505,328.8153 L 712.13922,329.78475 L 714.95419,328.35186 L 720.73264,324.82222 L 724.69501,322.6372 L 724.69501,320.45219 L 726.51109,318.60333 L 731.13386,313.05675 L 735.42643,309.35903 L 738.7284,305.32516 z \",\n    \"M 152.15345,458.16063 L 151.84095,540.66102 L 153.40345,541.59852 L 156.37222,541.75477 L 157.77847,540.66102 L 160.27848,540.66102 L 160.43474,543.47353 L 167.15352,550.03606 L 167.62227,552.53607 L 170.90353,550.66106 L 171.52854,550.50481 L 171.84104,547.53605 L 173.24729,545.97354 L 174.34105,545.81729 L 176.21606,544.41103 L 179.18482,546.44229 L 179.80983,549.25481 L 181.68483,550.34856 L 182.77859,552.69232 L 186.52861,554.41108 L 189.80987,560.19236 L 192.46613,563.94237 L 194.65364,566.59864 L 196.0599,570.1924 L 200.90367,571.91116 L 205.9037,573.94242 L 206.8412,578.16119 L 207.30995,581.12995 L 206.37245,584.41122 L 204.65369,586.59873 L 203.09118,585.81748 L 201.68493,582.84871 L 199.02866,581.44246 L 197.30991,580.3487 L 196.52865,581.12995 L 197.93491,583.78622 L 198.09116,587.37998 L 196.9974,587.84873 L 195.1224,585.97373 L 193.09114,584.72372 L 193.55989,586.28623 L 194.80989,588.00499 L 194.02864,588.78624 C 194.02864,588.78624 193.24739,588.47374 192.77864,587.84873 C 192.30988,587.22373 190.74738,584.56747 190.74738,584.56747 L 189.80987,582.37996 C 189.80987,582.37996 189.49737,583.62997 188.87237,583.31746 C 188.24736,583.00496 187.62236,581.91121 187.62236,581.91121 L 189.34112,580.0362 L 187.93486,578.62994 L 187.93486,573.78617 L 187.15361,573.78617 L 186.37236,577.06743 L 185.2786,577.53619 L 184.3411,573.94242 L 183.71609,570.34865 L 182.93484,569.8799 L 183.24734,575.34868 L 183.24734,576.44243 L 181.84108,575.19243 L 178.40357,569.41115 L 176.37231,568.9424 L 175.74731,565.34863 L 174.1848,562.53612 L 172.62229,561.44236 L 172.62229,559.25485 L 174.65355,558.00485 L 174.1848,557.69235 L 171.68479,558.31735 L 168.40352,555.97359 L 165.90351,553.16107 L 161.21599,550.66106 L 157.30972,548.16105 L 158.55973,545.03604 L 158.55973,543.47353 L 156.84097,545.03604 L 154.02846,546.12979 L 150.43469,545.03604 L 144.96591,542.69228 L 139.65339,542.69228 L 139.02839,543.16103 L 132.77836,539.41101 L 130.7471,539.09851 L 128.09084,533.47348 L 124.65332,533.78598 L 121.2158,535.19224 L 121.68456,539.56726 L 122.77831,536.75475 L 123.71582,537.06725 L 122.30956,541.28602 L 125.43457,538.62976 L 126.05958,540.19226 L 122.30956,544.41103 L 121.05955,544.09853 L 120.5908,542.22352 L 119.3408,541.44227 L 118.09079,542.53603 L 115.43453,540.81727 L 112.46576,542.84853 L 110.74701,544.87979 L 107.46574,546.91105 L 102.93447,546.75479 L 102.46572,544.72354 L 106.05948,544.09853 L 106.05948,542.84853 L 103.87197,542.22352 L 104.80948,539.87976 L 106.99699,536.12975 L 106.99699,534.41099 L 107.15324,533.62973 L 111.37201,531.44222 L 112.30951,532.69223 L 114.96578,532.69223 L 113.71577,530.19222 L 110.122,529.87972 L 105.27823,532.53598 L 102.93447,535.81724 L 101.21571,538.31726 L 100.12196,540.50477 L 96.059441,541.91102 L 93.090671,544.41103 L 92.778171,545.97354 L 94.965681,546.91105 L 95.746941,548.9423 L 93.090671,552.06732 L 86.840651,556.12984 L 79.340608,560.19236 L 77.309348,561.28611 L 72.153076,562.37987 L 66.996796,564.56738 L 68.715556,565.81738 L 67.309296,567.22364 L 66.840546,568.31739 L 64.184286,567.37989 L 61.059276,567.53614 L 60.278016,569.72365 L 59.340516,569.72365 L 59.653016,567.37989 L 56.215496,568.6299 L 53.402986,569.5674 L 50.121721,568.31739 L 47.309208,570.1924 L 44.184194,570.1924 L 42.152934,571.44241 L 40.590427,572.22366 L 38.559168,571.91116 L 36.059156,570.81741 L 33.871646,571.44241 L 32.934142,572.37991 L 31.371634,571.28616 L 31.371634,569.41115 L 34.340398,568.16114 L 40.434176,568.78615 L 44.652946,567.22364 L 46.684205,565.19238 L 49.496718,564.56738 L 51.215476,563.78612 L 53.871739,563.94237 L 55.434246,565.19238 L 56.371746,564.87988 L 58.559256,562.22362 L 61.528026,561.28611 L 64.809286,560.66111 L 66.059296,560.34861 L 66.684296,560.81736 L 67.465556,560.81736 L 68.715556,557.22359 L 72.621826,555.81734 L 74.496836,552.22357 L 76.684348,547.84855 L 78.246858,546.44229 L 78.559358,543.94228 L 76.996848,545.19229 L 73.715576,545.81729 L 73.090576,543.47353 L 71.840576,543.16103 L 70.903066,544.09853 L 70.746816,546.91105 L 69.340556,546.75479 L 67.934306,541.12977 L 66.684296,542.37977 L 65.590546,541.91102 L 65.278046,540.03601 L 61.371776,540.19226 L 59.340516,541.28602 L 56.840506,540.97352 L 58.246756,539.56726 L 58.715506,537.06725 L 58.090506,535.19224 L 59.496766,534.25474 L 60.746766,534.09849 L 60.121766,532.37973 L 60.121766,528.16096 L 59.184266,527.22345 L 58.403006,528.62971 L 52.465482,528.62971 L 51.059226,527.3797 L 50.434223,523.62969 L 48.402963,520.19217 L 48.402963,519.25467 L 50.434223,518.47341 L 50.590473,516.44215 L 51.684228,515.3484 L 50.902975,514.87965 L 49.652969,515.3484 L 48.559214,512.69214 L 49.496718,507.84836 L 53.871739,504.72335 L 56.371746,503.16084 L 58.246756,499.56708 L 60.903026,498.31707 L 63.403036,499.41083 L 63.715536,501.75459 L 66.059296,501.44208 L 69.184306,499.09832 L 70.746816,499.72333 L 71.684316,500.34833 L 73.246826,500.34833 L 75.434338,499.09832 L 76.215598,494.87955 C 76.215598,494.87955 76.528098,492.06704 77.153098,491.59829 C 77.778098,491.12954 78.090598,490.66079 78.090598,490.66079 L 76.996848,488.78578 L 74.496836,489.56703 L 71.371816,490.34828 L 69.496806,489.87953 L 66.059296,488.16077 L 61.215526,488.00452 L 57.778006,484.41076 L 58.246756,480.66074 L 58.871766,478.31698 L 56.840506,476.59822 L 54.965494,473.00445 L 55.434246,472.2232 L 61.996776,471.75445 L 64.028036,471.75445 L 64.965536,472.69195 L 65.590546,472.69195 L 65.434296,471.12944 L 69.184306,470.50444 L 71.684316,470.81694 L 73.090576,471.9107 L 71.684316,473.94196 L 71.215566,475.34821 L 73.871836,476.91072 L 78.715608,478.62948 L 80.434368,477.69198 L 78.246858,473.47321 L 77.309348,470.34819 L 78.246858,469.56694 L 74.965588,467.69193 L 74.496836,466.59817 L 74.965588,465.03567 L 74.184336,461.28565 L 71.371816,456.75438 L 69.028056,452.69186 L 71.840576,450.81685 L 74.965588,450.81685 L 76.684348,451.44185 L 80.746868,451.2856 L 84.340631,447.84809 L 85.434391,444.87932 L 89.028161,442.53556 L 90.590661,443.47307 L 93.246921,442.84806 L 96.840691,440.8168 L 97.934451,440.66055 L 98.871951,441.44181 L 103.24697,441.28556 L 105.90323,438.31679 L 106.99699,438.31679 L 110.4345,440.66055 L 112.30951,442.69181 L 111.84076,443.78557 L 112.46576,444.87932 L 114.02827,443.31682 L 117.77829,443.62932 L 118.09079,447.22308 L 119.9658,448.62934 L 126.84083,449.25434 L 132.93461,453.31686 L 134.34086,452.37936 L 139.34089,454.87937 L 141.37215,454.25437 L 143.24716,453.47311 L 147.93468,455.34812 L 152.15345,458.16063 z M 40.902929,486.12951 L 42.934188,491.28579 L 42.777937,492.22329 L 39.965424,491.91079 L 38.246666,488.00452 L 36.527908,486.59827 L 34.184147,486.59827 L 34.027897,484.09825 L 35.746655,481.75449 L 36.84041,484.09825 L 38.246666,485.50451 L 40.902929,486.12951 z M 38.402917,518.47341 L 41.996684,519.25467 L 45.59045,520.19217 L 46.371704,521.12968 L 44.809197,524.72344 L 41.840433,524.56719 L 38.559168,521.12968 L 38.402917,518.47341 z M 18.402824,504.8796 L 19.49658,507.37961 L 20.590335,508.94212 L 19.49658,509.72337 L 17.46532,506.75461 L 17.46532,504.8796 L 18.402824,504.8796 z M 5.1215129,575.50493 L 8.4027779,573.31742 L 11.684043,572.37991 L 14.184055,572.69241 L 14.652807,574.25492 L 16.527816,574.72367 L 18.402824,572.84867 L 18.090323,571.28616 L 20.746585,570.66116 L 23.559098,573.16117 L 22.465343,574.87992 L 18.246574,575.97368 L 15.590311,575.50493 L 11.996545,574.41117 L 7.7777749,575.81743 L 6.2152679,576.12993 L 5.1215129,575.50493 z M 52.465482,571.12991 L 54.027989,573.00492 L 56.059246,571.44241 L 54.652992,570.1924 L 52.465482,571.12991 z M 55.277995,574.09867 L 56.371746,571.91116 L 58.403006,572.22366 L 57.621756,574.09867 L 55.277995,574.09867 z M 78.090598,572.22366 L 79.496858,573.94242 L 80.434368,572.84867 L 79.653108,570.97366 L 78.090598,572.22366 z M 86.528141,560.19236 L 87.621901,565.81738 L 90.434411,566.59864 L 95.278181,563.78612 L 99.496951,561.28611 L 97.934451,558.94235 L 98.403201,556.59859 L 96.371941,557.8486 L 93.559431,557.06734 L 95.121931,555.97359 L 96.996941,556.75484 L 100.74696,555.03608 L 101.21571,553.62983 L 98.871951,552.84857 L 99.653201,550.97356 L 96.996941,552.84857 L 92.465671,556.28609 L 87.778151,559.0986 L 86.528141,560.19236 z M 127.46583,540.97352 L 129.80959,539.56726 L 128.87209,537.8485 L 127.15333,538.78601 L 127.46583,540.97352 z \"\n];\ngeo_data = geo_data.map(function (path) {\n    item = <a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>(\"Ext.draw.sprite.Path\", {\n        path: path,\n        fx: { duration: 200 },\n        highlightCfg: { \n            shadowColor: 'black', \n            shadowBlur: 8,\n            shadowOffsetX: 3,\n            shadowOffsetY: 3,\n            fillStyle: '#88f', \n            zIndex: 100 \n        },\n        modifiers: ['highlight']\n    });\n    return item;\n});\ngeo_data[27].setAttributes({highlight: true});\nvar lastHighlight = geo_data[27];\n// Create draw component with a yellow circle in it\n<a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>(\"Ext.draw.Component\", {\n    fullscreen: true,\n    sprites: geo_data,\n    resizeHandler: function (size) {\n        var surface = this.getSurface('main'),\n            bbox = surface.getItems().getBBox(true);\n        scaling = Math.min((size.width - 30) / bbox.width, (size.height - 30) / bbox.height) * 0.95;\n        surface.setRegion([0, 0, size.width, size.height]);\n        surface.getItems().setAttributes({\n            fill: '#ddf',\n            stroke: 'black',\n            translationX: -(bbox.x + bbox.width / 2) * scaling + size.width / 2,\n            translationY: -(bbox.y + bbox.height / 2) * scaling + size.height / 2,\n            scalingCenterX: 0,\n            scalingCenterY: 0,\n            scalingX: scaling,\n            scalingY: scaling\n        });\n    },\n    listeners: {\n        element: 'element',\n        tap: function (e) {\n            var items = this.getSurface().getItems().items,\n                i, ln = items.length, item, \n                mat = items[0].attr.inverseMatrix,\n                x = mat.x(e.pageX, e.pageY),\n                y = mat.y(e.pageX, e.pageY),\n                bbox, highlight = null;\n            for (i = 0; i &lt; ln; i += 1) {\n                item = items[i];\n                bbox = item.getBBox(true);\n                if (bbox.x &lt;= x &amp;&amp; x &lt;= bbox.x + bbox.width &amp;&amp; bbox.y &lt;= y &amp;&amp; bbox.y &lt;= bbox.y + bbox.height) {\n                    if (item.attr.path.isPointInPath(x, y)) {\n                        highlight = item;\n                        break;\n                    }\n                }\n            }\n            if (lastHighlight !== highlight) {\n                if (lastHighlight) {\n                    lastHighlight.setAttributes({highlighted: false});\n                }\n                if (highlight) {\n                    highlight.setAttributes({highlighted: true});\n                }\n                lastHighlight = highlight;\n            }\n        }\n    }\n});\n</code></pre>\n\n<p>As you may have noticed in the above example, the HiDPI Display is detected and the pixel rate will be boosted to adapt the resolution. Note that this happens transparently to both users and developers. A \"pixel\" used in Surface is always as the same size as in common HTML page, no matter if the display device is HiDPI. The charts will no longer be fuzzy on Retina devices.</p>\n\n<p>The draw package also supports a SVG backend. Simply set \"Ext.draw.engine.SVG\" as the default engine for you Draw Component, and it works all as expected. Continue using the Canvas API to draw procedurally and forget about the backend, it's all abstracted for you.</p>\n\n<h3>Sprites</h3>\n\n<p>Sprites are objects rendered on a drawing surface. They are added to a surface in the <code>getItems()</code> collection. The example below includes a sprite with the <code>type</code> <code>circle</code>, a <code>radius</code> of <code>100</code> and a yellowish color (<code>#ff8</code>), which causes a yellow circle to appear in the top left corner of the surface.</p>\n\n<pre class='inline-example '><code>// Click at \"Live Preview\" button above to switch to runnable example.\n// Create draw component with a yellow circle in it\n<a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>(\"Ext.draw.Component\", {\n    fullscreen: true,\n    sprites: [\n        {\n            type: 'circle',\n            fillStyle: '#ff8',\n            strokeStyle: 'black',\n            lineWidth: 3,\n            radius: 100,\n            x: 100,\n            y: 100\n        }\n    ]\n});\n</code></pre>\n\n<p>In this new version of the draw package sprites are represented by their own classes. This makes it much easier to modify them along with also improving the performance.</p>\n\n<p>Additionally, the draw package introduces the following enhancements to sprites:</p>\n\n<ul>\n<li><strong>Attribute definitions</strong> - To create custom sprite types, you will need to define additional attributes that can also be changed by the <code>setAttribute</code> method. You can define the data type of an attribute, the method of interpolation for animation, as well as the callbacks to call after the attributes have been changed.</li>\n<li><strong>Modifiers</strong> - The modifiers are decorators to the original attributes. Modifiers are chained together like a pipeline carefully separated so that each modifier does not need the knowledge of the others, and the attributes will be decorated though the pipeline. You can chain and unchain the modifiers very easily and the appearance of the sprite will be changed correctly.</li>\n<li><strong>Flyweight instancing</strong> - The chart package provides markers as well as labels in every kind of chart. You can register any sprite as the template of an instancing sprite which will basically render the same object multiple times in different places.</li>\n</ul>\n\n\n<p>Each of these features is described in a subsequent section.</p>\n\n<p>Besides the <code>Circle</code> type, you can use other sprite types. For example:</p>\n\n<ul>\n<li><strong>rect</strong> - Creates a rectangle. You can make round corners by setting its <code>radius</code> attribute.</li>\n<li><strong>image</strong> - Creates a bitmap image that will be rendered on the surface.</li>\n<li><strong>path</strong> - Create arbitrary shapes with the <a href=\"http://www.w3.org/TR/SVG/paths.html\">SVG path syntax</a>. This is the most powerful primitive sprite type. For a tutorial on getting started with the SVG path syntax, see the <a href=\"https://developer.mozilla.org/en/SVG/Tutorial/Paths\">Mozilla Developer Network</a>.</li>\n</ul>\n\n\n<p>Unlike the old draw package, attributes are defined with a naming convention conforming to HTML Canvas API rather than SVG API. However, you can still use the old naming convention conforming to SVG API due to the aliasing mechanism in attribute definition.</p>\n\n<p>In addition, sprites can be transformed using the following attributes:</p>\n\n<ul>\n<li><strong>scalingX</strong> - The x factor on scaling.</li>\n<li><strong>scalingY</strong> - The y factor on scaling.</li>\n<li><strong>scalingCenterX</strong> - The x coordinate of the origin to perform scaling. <code>null</code> to refer to the center of the sprite.</li>\n<li><strong>scalingCenterY</strong> - The y coordinate of the origin to perform scaling. <code>null</code> to refer to the center of the sprite.</li>\n<li><strong>rotationRads</strong> - The angle of the clockwise rotation in radians.</li>\n<li><strong>rotationCenterX</strong> - The x coordinate of center of the rotation. <code>null</code> to refer to the center of the sprite.</li>\n<li><strong>rotationCenterY</strong> - The y coordinate of center of the rotation. <code>null</code> to refer to the center of the sprite.</li>\n<li><strong>translationX</strong> - The translation on x direction.</li>\n<li><strong>translationY</strong> - The translation on y direction.</li>\n</ul>\n\n\n<p>We no longer store transform objects in the set of attributes, but you can continue to use transform objects to set those attributes. The definition of transform objects are compatible with the old draw package. The transforms will be performed in the order of scaling, then rotation and then translation.</p>\n\n<p>After setting any of the above transform attributes, the <code>matrix</code> and <code>inverseMatrix</code> attributes will be updated. In the new draw package, you can also simply set the <code>matrix</code> attributes directly. The matrix you give will be extracted into the above attributes to retain consistency.</p>\n\n<h3>Attribute Definitions And Modifiers</h3>\n\n<p>The Sencha Touch 2.1 draw package also introduces a mechanism for sprite attribute definitions as well as sprite modifiers. They are a huge improvement on both maintainability and performance. These are essential if you want to write your own sprites. Let us take a closer look at each of these features:</p>\n\n<h4>Attribute Definition</h4>\n\n<p>Attribute definition enables you to define custom attributes of a custom sprite class to perform \"lazy\" updates. The primary purpose of an attribute definition is to define how data is used for changing the content of a set of attributes when the <code>setAttributes</code> method is called. Each sprite has a member called <code>attr</code> (the \"set of attributes\" of the sprite.) All sprite states – as well as caches – are stored in the set of attributes. This architecture deliberately separate the \"Model\" (attributes) from the \"View\" (sprite.) This way we can share the same sprite to display a different set of attributes, which is how flyweight instancing works.</p>\n\n<p>Attribute definitions are given as below (a snippet from Ext.chart.series.sprite.Line):</p>\n\n<pre><code>...\ninheritableStatics: {\n    def: {\n        processors: {\n            smooth: 'bool',\n            step: 'bool',\n            preciseStroke: 'bool'\n        },\n\n        defaults: {\n            smooth: false,\n            step: false,\n            preciseStroke: false\n        },\n\n        dirtyTriggers: {\n            dataX: 'dataX,bbox,smooth',\n            dataY: 'dataY,bbox,smooth',\n            smooth: 'smooth'\n        },\n\n        updaters: {\n            \"smooth\": function (attr) {\n                if (attr.smooth &amp;&amp; attr.dataX &amp;&amp; attr.dataY) {\n                    this.smoothX = Ext.draw.Draw.spline(attr.dataX);\n                    this.smoothY = Ext.draw.Draw.spline(attr.dataY);\n                } else {\n                    delete this.smoothX;\n                    delete this.smoothY;\n                }\n            }\n        }\n    }\n},\n...\n</code></pre>\n\n<p>The attributes definitions are defined in the <code>inheritableStatics</code> section of a class definition, they will be inherited automatically through class inheritance. Also because it is defined as a static member, the object that manages the mechanism will be created only once for each class. Due to the separation of attributes and sprites, we are able to use the same attribute manager (Ext.draw.sprite.AttributeDefinition) to process all the sprites of the same type.</p>\n\n<p>Attribute definitions can define appliers (called <code>processors</code> in the code) and updaters in a relatively similar way as the Sencha Touch config system, but with batched update processors for better performance. For example, when you change the <code>width</code> and <code>height</code> of a rectangle sprite, its cached path will be updated. The draw package batches the updating if you set the both attributes in the same <code>setAttributes</code> call, so that the path needs to be calculated only once. Appliers of attribute definitions, or processors, enable you to check and normalize a value before it is applied to the set of attributes. Since names can be used as references to predefined processors, this approach is very convenient and vastly enhances maintainability. Attribute definitions also enable you to define aliases to the attribute items so you can use legacy code using the old Sencha Touch 1.0 naming conventions without a huge compatibility impact.</p>\n\n<h4>Modifiers</h4>\n\n<p>Modifiers enable you to add changes to a set of attributes. A modifier is an adaptation of the <a href=\"http://en.wikipedia.org/wiki/Decorator_pattern\">Decorator pattern</a>. A sprite can have a list of modifiers that are chained together to process the content of an attribute set. In this way, a modifier is like a pipeline of filters that build up the resulting attributes progressively. For instance, when you query the value of an attribute set, the Highlight modifier changes certain attributes to be its highlighted value; similarly, the Animation modifier generates the current value for each animated attribute for each frame.</p>\n\n<p>Modifiers are designed to work independently. This increases maintainability by making each modification modular. Previously, highlighting a sprite involved working with an animation inside the highlighting code, which involved about ten lines of similar, potentially error-prone code every time you want to do the trick. You need to use a different way to highlight a sprite depending on whether it is in an animation or not. In the animation part, you need to do the same thing again. Now however, with the use of modifiers, highlighting is done in only two lines and only involves setting the <code>highlighted</code> attribute that will activate the highlight modifier. The modifier highlights the sprite exactly as expected without needing to know the information about the animation.</p>\n\n<p>Modifiers are implemented in such a way that queries to the attribute are actually querying a property that directly exists on the JavaScript object. The attributes set are structured as a prototype chain controlled by modifiers.</p>\n\n<p>In the <code>setAttributes</code> method, the changes you want to make to the attributes set is called a \"change request\". <code>setAttributes</code> will call the <code>pushDown</code> method against the request at the end of the modifier chain. The modifier, who can actually modify the change request, is responsible for passing the change request down through the chain when its necessary (a counter example is when the modifier knows that no changes will be made after this point, then it can stop the <code>pushDown</code>). The remaining changes will be popped up as a return value. The modifiers can also modify the popped up changes and/or place the changes to where (in the prototype chain) it should actually be placed.</p>\n\n<p>The implementation of modifier is sophisticated and might be hard to understand. But in practice it is quite simple to use. In most cases you don't need to know what's behind it and it simply works. For example, you don't need to initiate an update loop or \"start\" something to use an <code>Animation</code> modifier. You simply set the duration time of the modifier and anytime you change an attribute of the sprite it will start a smooth animation.</p>\n\n<pre class='inline-example '><code><a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>(\"Ext.draw.Component\", {\n    fullscreen: true,\n    background: 'white',\n    sprites: [{\n        zIndex: 30,\n        type: 'circle',\n        radius: 30,\n        fill: 'gray',\n        stroke: 'black',\n        fx: {\n           duration: 300\n        },\n        translate: {\n            x: 180,\n            y: 90\n        }\n    }, {\n        type: 'text',\n        fontSize: 18,\n        fill: '#ddd',\n        text: 'Click the screen to watch the circle move',\n        textAlign: 'center',\n        x: 240,\n        y: 280\n    }],\n    listeners: {\n        element: \"element\",\n        touchstart: function (e) {\n            var sprite = this.getSurface().getItems().items[1];\n            sprite.setAttributes({\n                translationX: e.pageX,\n                translationY: e.pageY\n            });\n        }\n    }\n});\n</code></pre>\n\n<h3>Flyweight Instancing Of Sprites</h3>\n\n<p>Another enhancement introduced with the Sencha Touch 2.1 draw package is a feature called flyweight instancing, which provides major performance improvements.</p>\n\n<p>The new chart package represents many visual elements of a chart as \"markers\" -- flyweight sprites forked from a single set of attributes prototype. These markers share the same sprite object. In this way, a sprite defines the logic for rendering (hence the \"View\") rather than the data (hence the \"Model\"). Creating massive number of sprites is a heavyweight operation and can be computationally expensive. Instead, for a set of objects that differ slightly, only the incremental data for rendering is created, which saves a significant amount of memory. This technique is often referred to as \"instancing rendering\" in other computer graphics fields. In the new draw package an \"Instancing Sprite\" is a container of the forked instances and renders them using instancing rendering.</p>\n\n<p>The chart package provides \"markers\" in every chart type. Markers are supported by a subclass of instancing sprite called <code>Markers</code> sprite. The main difference between markers and regular instancing sprites is that markers are attached to another sprite called \"marker holders\". Whenever the marker holders are drawn, the marker sprite will collect information about the changes on the instances. While previously a marker was only a small subset of a sprite config object, in the current version you can use you own template and it can be anything and can appear anywhere.</p>\n\n<h2 id='drawing_and_charting-section-2'>Chart Component Overview</h2>\n\n<p>The chart package consists of a hierarchy of classes to provide data visualization functionality.\nThese include series, axes, interactions and mechanisms to implement markers and legend.\nThis section provides an overview on how these classes are tied together and what functionality is included in each\nclass. The following sections cover the specific axes, series and interactions.</p>\n\n<pre class='inline-example preview'><code>var store = <a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>(\"<a href=\"#!/api/Ext.data.Store\" rel=\"Ext.data.Store\" class=\"docClass\">Ext.data.Store</a>\", {\n    fields: ['name', 'value1', 'value2'],\n    data: [\n        { name: 'Jan', value1: 5, value2: 412 },\n        { name: 'Feb', value1: 23, value2: 142 },\n        { name: 'Mar', value1: 83, value2: 113 },\n        { name: 'Apr', value1: 233, value2: 834 },\n        { name: 'May', value1: 509, value2: 1024 },\n        { name: 'Jun', value1: 864, value2: 1102 },\n        { name: 'Jul', value1: 1144, value2: 425 },\n        { name: 'Aug', value1: 1179, value2: 324 },\n        { name: 'Sep', value1: 946, value2: 39 },\n        { name: 'Oct', value1: 591, value2: 1142 },\n        { name: 'Nov', value1: 288, value2: 523 },\n        { name: 'Dec', value1: 109, value2: 634 }\n    ]\n});\n<a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>(\"<a href=\"#!/api/Ext.Panel\" rel=\"Ext.Panel\" class=\"docClass\">Ext.Panel</a>\", {\n    fullscreen: true,\n    layout: 'fit',\n    style: 'background: white',\n    items: [\n        {\n            xtype: 'chart',\n            background: \"none\",\n            store: store,\n            animate: true,\n            interactions: ['panzoom', 'itemhighlight'],\n            legend: {\n                position: \"bottom\"\n            },\n            series: [\n                {\n                    type: 'line',\n                    xField: 'name',\n                    yField: 'value1',\n                    title: 'Line',\n                    style: {\n                        smooth: true,\n                        stroke: '#115fa6',\n                        lineWidth: 3,\n                        shadowColor: 'rgba(0,0,0,0.7)',\n                        shadowBlur: 10,\n                        shadowOffsetX: 3,\n                        shadowOffsetY: 3\n                    },\n                    highlightCfg: {\n                        scale: 2\n                    },\n                    marker: {\n                        type: 'circle',\n                        stroke: '#0d1f96',\n                        fill: '#115fa6',\n                        lineWidth: 2,\n                        radius: 4,\n                        shadowColor: 'rgba(0,0,0,0.7)',\n                        shadowBlur: 10,\n                        shadowOffsetX: 3,\n                        shadowOffsetY: 3,\n                        fx: {duration: 300}\n                    }\n                },\n                {\n                    type: 'bar',\n                    xField: 'name',\n                    yField: ['value2'],\n                    title: ['Bar'],\n                    style: {\n                        maxBarWidth: 15,\n                        lineWidth: 1.5,\n                        fill: \"#a61120\",\n                        stroke: 'black',\n                        shadowColor: 'rgba(0,0,0,0.7)',\n                        shadowBlur: 10,\n                        shadowOffsetX: 3,\n                        shadowOffsetY: 3\n                    }\n                }\n            ],\n            axes: [\n                {\n                    type: 'numeric',\n                    position: 'left',\n                    grid: {\n                        odd: {\n                            fill: '#fafafa'\n                        }\n                    },\n                    style: {\n                        axisLine: false,\n                        estStepSize: 20,\n                        stroke: '#ddd'\n                    },\n                    minimum: 0,\n                    maximum: 1210\n                },\n                {\n                    type: 'category',\n                    position: 'bottom',\n                    visibleRange: [0, 0.7],\n                    style: {\n                        estStepSize: 1,\n                        stroke: '#999'\n                    }\n                }\n            ]\n        }, {\n            xtype: 'container',\n            left: 40,\n            top: -10,\n            width: 160,\n            height: 160,\n            layout: 'fit',\n            items: [{\n                interactions: ['rotate', 'itemhighlight'],\n                style: 'z-index: 5',\n                xtype: 'polar',\n                store: store,\n                innerPadding: 16,\n                series: [\n                    {\n                        type: 'pie',\n                        xField: 'value2',\n                        donut: 30,\n                        highlightCfg: {\n                            margin: 15\n                        },\n                        style: {\n                            fillOpacity: 0.9,\n                            stroke: \"#444\"\n                        },\n                        subStyle: {\n                            fillStyle: [\"#115fa6\", \"#94ae0a\", \"#a61120\", \"#ff8809\", \"#ffd13e\", \"#a61187\", \"#24ad9a\", \"#7c7474\", \"#a66111\"]\n                        }\n                    }\n                ]\n            }]\n        }\n\n    ]\n});\n</code></pre>\n\n<h3>The Chart Component Class</h3>\n\n<p>All types of the chart components are extended from  The abstract chart class,\nwhich extends Ext.draw.Component.\nA chart component is the container to manage series and axes.\nIt is responsible to layout the series and axes\nevery time when the size is changed. An implementation of the abstract class must override the <code>performLayout</code> method.\nFor example, cartesian chart needs to respond to the changes of the thickness of the axes and recalculate the series\narea.</p>\n\n<p>In the new package, there are three type of charts:</p>\n\n<ul>\n<li><strong>Cartesian Chart</strong> - This class is used to layout series and axes in an cartesian\ncoordinate system.\nAnother name <code>Ext.chart.Chart</code> is also used to refer to this class.</li>\n<li><strong>Polar Chart</strong> - This class is used ot layout sereis and axes in an polay coordinate\nsystem.</li>\n<li><strong>Space Filling Chart</strong> - This class simply fills the series to the size of the\ncomponent. No axes can be used in this type of chart.</li>\n</ul>\n\n\n<p>A chart component manages:</p>\n\n<ul>\n<li><strong>Axes</strong> - These are accessed through <code>Ext.chart.series.Series</code> and represent all the axes being defined and drawn\nfor this visualization. This is a mixed collection.</li>\n<li><strong>Series</strong> - These are accessed through <code>Ext.chart.series.Series</code> and represent all the series being drawn for the\nchart. This could be line, bar, scatter, and so on. This is also a mixed collection.</li>\n<li><strong>Interactions</strong> - These are controllers that directly manipulate the series and axes when certain touch gesture is\nrecognized.</li>\n<li><strong>Legend Store</strong> - This represents the legend information collected from series. Normally you can attach a data list\nto this store and get automatic updated on the changes of legend information.</li>\n</ul>\n\n\n<p>Chart component delegates touch events to different areas of the chart, such as the axes, series, and so on.\nYou can listen to the \"itemXXXX\" events directly on the chart component and it will delegate the events from registered\nseries:</p>\n\n<pre><code>chart.on({\n    'itemtap': function(series, item, e) {\n       alert('An item from ' + series.id + ' has been tapped!');\n    }\n});\n</code></pre>\n\n<h2 id='drawing_and_charting-section-3'>Axes</h2>\n\n<p>In Sencha Touch 2.1 chart package, we provided a class Ext.chart.axis.Axis to represent all kinds of axes.\nThe axis object works differently according to the position you dock the axis. There are 4 types of docking:</p>\n\n<ul>\n<li><strong>Left/Right</strong> - The axis will be vertical.</li>\n<li><strong>Top/Bottom</strong> - The axis will be horizontal.</li>\n<li><strong>Radial</strong> - The axis will be placed radially inside a polar chart to identify current radius.</li>\n<li><strong>Angular</strong> - The axis will be placed outside against the boundary of the polar chart to identify current angle.</li>\n</ul>\n\n\n<p>Axes helps series to map data values into coordinates. They are bound to the type of data that needs to be represented.\nThere are axes for category information (<code>Ext.chart.axis.Category</code>) and for quantitative information\n(<code>Ext.chart.axis.Numeric</code>). The Time axis (<code>Ext.chart.axis.Time</code>) enables the rendering of information over a specific\nperiod of time and updating with smooth animations.</p>\n\n<p>See the axis class documentation for specific information about each axis.\nThe series examples contained in subsequent sections of this guide provide axis configuration examples.</p>\n\n<p>You can enable grids to be attached to an axis object. Grids are placed perpendicular to the axis and drawn below any\nseries. Grids can be styled by given a style object as the <code>grid</code> field of the axis config. By given the <code>grid</code> field\na simple <code>true</code> value, it will draw the grid with default style.\nGrid style receives two special fields <code>even</code> and <code>odd</code> to specify additional styles for even and odd grid.\nYou can also set <code>fillStyle</code> of a grid, it will render an fill between two grids.</p>\n\n<p>The configuration shown previously produces minor ticks in the left axis for the line series, as shown in the following figure:</p>\n\n<pre class='inline-example '><code><a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>(\"Ext.chart.Chart\", {\n    fullscreen: true,\n    store: {\n        fields: ['name', 'value'],\n        data: [\n            { name: 'Jan', value: 110},\n            { name: 'Feb', value: 252},\n            { name: 'Mar', value: 952},\n            { name: 'Apr', value: 325},\n            { name: 'May', value: 123},\n            { name: 'Jun', value: 52},\n            { name: 'Jul', value: 1122},\n            { name: 'Aug', value: 35},\n            { name: 'Sep', value: 172},\n            { name: 'Oct', value: 752},\n            { name: 'Nov', value: 810},\n            { name: 'Dec', value: 410}\n        ]\n    },\n    animate: false,\n    interactions: ['panzoom'],\n    series: [\n        {\n            type: 'line',\n            xField: 'name',\n            yField: 'value',\n            style: {\n                fill: 'rgba(0,40,170,0.3)',\n                stroke: 'black'\n            }\n        }\n    ],\n    axes: [\n        {\n            type: 'numeric',\n            position: 'left',\n            title: 'Number of Hits',\n            minimum: 0,\n            maximum: 1200,\n            grid: {\n                fill: '#efefef',\n                odd: {\n                    fill: '#cdcdcd'\n                },\n                even: {\n                    lineWidth: 3\n                }\n            }\n        },\n        {\n            type: 'category',\n            position: 'bottom',\n            title: 'Month of the Year',\n            grid: true,\n            style: {\n                estStepSize: 1\n            }\n        }\n    ]\n});\n</code></pre>\n\n<h2 id='drawing_and_charting-section-4'>Series</h2>\n\n<p>Series is an abstract class extended by concrete visualizations, such as\nLine Series, Bar Series, or\nScatter Series.</p>\n\n<p>The Series class itself contains code that is common to all of these series, such as event handling, highlighting,\nmarkers, labels and so on.</p>\n\n<p>The following sections describe available series types. It also shows a complete series configuration example,\nincluding the Chart, Axis, and Series options. For more specific information, see the\nSeries documentation.</p>\n\n<h4>Area</h4>\n\n<p>The area series creates a stacked area chart, which is typically used to display multiple aggregated layers of\ninformation. As the same as other series, the area series must be added into the <code>series</code> config of the chart.</p>\n\n<p>You can specify multiple y fields on a stacked series like area series and bar series.</p>\n\n<p>A typical configuration object for the Area series looks like what you can see in the code of the demo:</p>\n\n<pre class='inline-example '><code><a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>(\"Ext.chart.CartesianChart\", {\n    fullscreen: true,\n    background: 'white',\n    store: {\n        fields: ['name', 'g1', 'g2', 'g3', 'g4', 'g5'],\n        data: [\n            {\"name\": \"Item-0\", \"g1\": 18.34, \"g2\": 0.04, \"g3\": 22.35, \"g4\": 10.50, \"g5\": 18.42},\n            {\"name\": \"Item-1\", \"g1\": 2.67, \"g2\": 14.87, \"g3\": 0.41, \"g4\": 19.15, \"g5\": 1.64},\n            {\"name\": \"Item-2\", \"g1\": 1.90, \"g2\": 5.72, \"g3\": 14.80, \"g4\": 38.93, \"g5\": 2.77},\n            {\"name\": \"Item-3\", \"g1\": 21.37, \"g2\": 2.13, \"g3\": 12.98, \"g4\": 63.82, \"g5\": 18.85},\n            {\"name\": \"Item-4\", \"g1\": 2.67, \"g2\": 8.53, \"g3\": 4.44, \"g4\": 87.39, \"g5\": 27.23},\n            {\"name\": \"Item-5\", \"g1\": 18.22, \"g2\": 4.62, \"g3\": 8.26, \"g4\": 97.63, \"g5\": 34.37},\n            {\"name\": \"Item-6\", \"g1\": 28.51, \"g2\": 12.43, \"g3\": 28.67, \"g4\": 108.29, \"g5\": 47.84},\n            {\"name\": \"Item-7\", \"g1\": 34.43, \"g2\": 4.40, \"g3\": 9.89, \"g4\": 127.27, \"g5\": 36.90},\n            {\"name\": \"Item-8\", \"g1\": 21.65, \"g2\": 13.87, \"g3\": 5.44, \"g4\": 112.49, \"g5\": 16.29},\n            {\"name\": \"Item-9\", \"g1\": 12.98, \"g2\": 35.44, \"g3\": 16.37, \"g4\": 135.54, \"g5\": 16.78},\n            {\"name\": \"Item-10\", \"g1\": 22.96, \"g2\": 38.70, \"g3\": 18.15, \"g4\": 114.96, \"g5\": 8.51},\n            {\"name\": \"Item-11\", \"g1\": 0.49, \"g2\": 51.90, \"g3\": 19.98, \"g4\": 95.00, \"g5\": 9.69},\n            {\"name\": \"Item-12\", \"g1\": 20.87, \"g2\": 62.07, \"g3\": 25.96, \"g4\": 87.79, \"g5\": 3.18},\n            {\"name\": \"Item-13\", \"g1\": 25.10, \"g2\": 78.46, \"g3\": 26.04, \"g4\": 91.54, \"g5\": 12.41},\n            {\"name\": \"Item-14\", \"g1\": 16.87, \"g2\": 56.80, \"g3\": 1.39, \"g4\": 71.78, \"g5\": 16.54}\n        ]\n    },\n\n    interactions: {\n        type: 'panzoom'\n    },\n\n    legend: {\n        position: 'right',\n        width: 80\n    },\n\n    axes: [\n        {\n            type: 'numeric',\n            position: 'left',\n            grid: true\n        },\n        {\n            type: 'category',\n            position: 'bottom',\n            visibleRange: [0, 0.25]\n        }\n    ],\n\n    series: [\n        {\n            type: 'area',\n            xField: 'name',\n            yField: ['g1', 'g2', 'g3', 'g4', 'g5'],\n            title: ['G1', 'G2', 'G3', 'G4', 'G5'],\n            style: {\n                stroke: 'black',\n                fillOpacity: 0.8\n            },\n            //cycles the red, green, and blue fill mode over the g1, g2,..., g5 items\n            //cycles the black and white strokes lines over the g1, g2,..., g5 items\n            //substyle parameters also override style parameters\n            subStyle: {\n                fill: [\"#115fa6\", \"#94ae0a\", \"#a61120\", \"#ff8809\", \"#ffd13e\", \"#a61187\", \"#24ad9a\", \"#7c7474\", \"#a66111\"]\n            }\n\n        }\n    ]\n});\n</code></pre>\n\n<h4>Bar</h4>\n\n<p>The bar series creates a stackable/groupable bar chart, which is typically used to display categorized numeric data that shows\nprogression or regression. Note that different from the old chart package, a bar series refers to a vertical\nbar series, or a column series. You can get the horizontal one by setting <code>flipXY</code> to the chart.</p>\n\n<p>A bar series can either be stacked or grouped. Set <code>stacked</code> config on the series to <code>false</code> to switch the series\nto be grouped.</p>\n\n<p>A sample Bar chart is shown in the following example:</p>\n\n<pre class='inline-example '><code><a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>(\"Ext.chart.CartesianChart\", {\n    fullscreen: true,\n    background: 'white',\n    flipXY: true,\n    store: {\n        fields: ['name', 'g1', 'g2', 'g3', 'g4', 'g5'],\n        data: [\n            {\"name\": \"Item-0\", \"g1\": 18.34, \"g2\": 0.04, \"g3\": 22.35, \"g4\": 10.50, \"g5\": 18.42},\n            {\"name\": \"Item-1\", \"g1\": 2.67, \"g2\": 14.87, \"g3\": 0.41, \"g4\": 19.15, \"g5\": 1.64},\n            {\"name\": \"Item-2\", \"g1\": 1.90, \"g2\": 5.72, \"g3\": 14.80, \"g4\": 38.93, \"g5\": 2.77},\n            {\"name\": \"Item-3\", \"g1\": 21.37, \"g2\": 2.13, \"g3\": 12.98, \"g4\": 63.82, \"g5\": 18.85},\n            {\"name\": \"Item-4\", \"g1\": 2.67, \"g2\": 8.53, \"g3\": 4.44, \"g4\": 87.39, \"g5\": 27.23},\n            {\"name\": \"Item-5\", \"g1\": 18.22, \"g2\": 4.62, \"g3\": 8.26, \"g4\": 97.63, \"g5\": 34.37},\n            {\"name\": \"Item-6\", \"g1\": 28.51, \"g2\": 12.43, \"g3\": 28.67, \"g4\": 108.29, \"g5\": 47.84},\n            {\"name\": \"Item-7\", \"g1\": 34.43, \"g2\": 4.40, \"g3\": 9.89, \"g4\": 127.27, \"g5\": 36.90},\n            {\"name\": \"Item-8\", \"g1\": 21.65, \"g2\": 13.87, \"g3\": 5.44, \"g4\": 112.49, \"g5\": 16.29},\n            {\"name\": \"Item-9\", \"g1\": 12.98, \"g2\": 35.44, \"g3\": 16.37, \"g4\": 135.54, \"g5\": 16.78},\n            {\"name\": \"Item-10\", \"g1\": 22.96, \"g2\": 38.70, \"g3\": 18.15, \"g4\": 114.96, \"g5\": 8.51},\n            {\"name\": \"Item-11\", \"g1\": 0.49, \"g2\": 51.90, \"g3\": 19.98, \"g4\": 95.00, \"g5\": 9.69},\n            {\"name\": \"Item-12\", \"g1\": 20.87, \"g2\": 62.07, \"g3\": 25.96, \"g4\": 87.79, \"g5\": 3.18},\n            {\"name\": \"Item-13\", \"g1\": 25.10, \"g2\": 78.46, \"g3\": 26.04, \"g4\": 91.54, \"g5\": 12.41},\n            {\"name\": \"Item-14\", \"g1\": 16.87, \"g2\": 56.80, \"g3\": 1.39, \"g4\": 71.78, \"g5\": 16.54}\n        ]\n    },\n\n    interactions: ['panzoom'],\n\n    //set legend configuration\n    legend: {\n        position: 'right',\n        width: 80\n    },\n\n    //define the x and y-axis configuration.\n    axes: [\n        {\n            type: 'numeric',\n            position: 'bottom',\n            grid: true,\n            minimum: 0\n        },\n        {\n            type: 'category',\n            position: 'left'\n        }\n    ],\n\n    //define the actual bar series.\n    series: [\n        {\n            type: 'bar',\n            xField: 'name',\n            yField: ['g1', 'g2', 'g3', 'g4', 'g5'],\n            axis: 'bottom',\n            highlight: true,\n            showInLegend: true,\n            style: {\n                stroke: 'rgb(40,40,40)',\n                maxBarWidth: 30\n            },\n            // Cycles the red, green, and blue fill mode over the 2008, 2009,.., 2011, 2012 items\n            // subStyle parameters also override style parameters\n            subStyle: {\n                fill: [\"#115fa6\", \"#94ae0a\", \"#a61120\", \"#ff8809\", \"#ffd13e\", \"#a61187\", \"#24ad9a\", \"#7c7474\", \"#a66111\"]\n            }\n        }\n    ]\n});\n</code></pre>\n\n<h4>Line</h4>\n\n<p>The line series creates a line chart, an alternative to a bar chart for showing categorized numeric data that\nshows progression or regression. The following example shows a typical configuration object for the Line series:</p>\n\n<pre class='inline-example '><code><a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>(\"Ext.chart.CartesianChart\", {\n    fullscreen: true,\n    store: {\n        fields: ['name', 'g1', 'g2', 'g3', 'g4', 'g5'],\n        data: [\n            {\"name\": \"Item-0\", \"g1\": 18.34, \"g2\": 0.04, \"g3\": 22.35, \"g4\": 10.50, \"g5\": 18.42},\n            {\"name\": \"Item-1\", \"g1\": 2.67, \"g2\": 14.87, \"g3\": 0.41, \"g4\": 19.15, \"g5\": 1.64},\n            {\"name\": \"Item-2\", \"g1\": 1.90, \"g2\": 5.72, \"g3\": 14.80, \"g4\": 38.93, \"g5\": 2.77},\n            {\"name\": \"Item-3\", \"g1\": 21.37, \"g2\": 2.13, \"g3\": 12.98, \"g4\": 63.82, \"g5\": 18.85},\n            {\"name\": \"Item-4\", \"g1\": 2.67, \"g2\": 8.53, \"g3\": 4.44, \"g4\": 87.39, \"g5\": 27.23},\n            {\"name\": \"Item-5\", \"g1\": 18.22, \"g2\": 4.62, \"g3\": 8.26, \"g4\": 97.63, \"g5\": 34.37},\n            {\"name\": \"Item-6\", \"g1\": 28.51, \"g2\": 12.43, \"g3\": 28.67, \"g4\": 108.29, \"g5\": 47.84},\n            {\"name\": \"Item-7\", \"g1\": 34.43, \"g2\": 4.40, \"g3\": 9.89, \"g4\": 127.27, \"g5\": 36.90},\n            {\"name\": \"Item-8\", \"g1\": 21.65, \"g2\": 13.87, \"g3\": 5.44, \"g4\": 112.49, \"g5\": 16.29},\n            {\"name\": \"Item-9\", \"g1\": 12.98, \"g2\": 35.44, \"g3\": 16.37, \"g4\": 135.54, \"g5\": 16.78},\n            {\"name\": \"Item-10\", \"g1\": 22.96, \"g2\": 38.70, \"g3\": 18.15, \"g4\": 114.96, \"g5\": 8.51},\n            {\"name\": \"Item-11\", \"g1\": 0.49, \"g2\": 51.90, \"g3\": 19.98, \"g4\": 95.00, \"g5\": 9.69},\n            {\"name\": \"Item-12\", \"g1\": 20.87, \"g2\": 62.07, \"g3\": 25.96, \"g4\": 87.79, \"g5\": 3.18},\n            {\"name\": \"Item-13\", \"g1\": 25.10, \"g2\": 78.46, \"g3\": 26.04, \"g4\": 91.54, \"g5\": 12.41},\n            {\"name\": \"Item-14\", \"g1\": 16.87, \"g2\": 56.80, \"g3\": 1.39, \"g4\": 71.78, \"g5\": 16.54}\n        ]\n    },\n    background: 'white',\n    interactions: ['panzoom'],\n\n    legend: {\n        position: 'bottom'\n    },\n\n    //define x and y-axis.\n    axes: [\n        {\n            type: 'numeric',\n            position: 'left'\n        },\n        {\n            type: 'category',\n            visibleRange: [0, 1],\n            position: 'bottom'\n        }\n    ],\n    //define the actual series\n    series: [{\n        type: 'line',\n        xField: 'name',\n        yField: 'g1',\n        title: 'Normal',\n        style: {\n            fill: \"#115fa6\",\n            stroke: \"#115fa6\",\n            fillOpacity: 0.6,\n            miterLimit: 3,\n            lineCap: 'miter',\n            lineWidth: 2\n        }\n    }, {\n        type: 'line',\n        xField: 'name',\n        yField: 'g2',\n        title: 'Smooth',\n        style: {\n            smooth: true,\n            stroke: \"#94ae0a\",\n            fillOpacity: 0.6,\n            miterLimit: 3,\n            lineCap: 'miter',\n            lineWidth: 2\n        }\n    }, {\n        type: 'line',\n        xField: 'name',\n        yField: 'g3',\n        title: 'Step line',\n        style: {\n            step: true,\n            stroke: \"#a61120\",\n            fillOpacity: 0.6,\n            miterLimit: 3,\n            lineCap: 'miter',\n            lineWidth: 2\n        }\n    }]\n});\n</code></pre>\n\n<h4>Pie</h4>\n\n<p>The Pie series creates a pie chart, a great way to display quantitative information for a number of categories\nthat also have a meaning as a whole, for example, all 12 months of a given year.</p>\n\n<p>Note that unless all the previous series, pie series and radar series are polar series. You cannot use them with a\ncartesian chart. Instead, they must be contained in a polar chart.</p>\n\n<p>A Pie chart example is given as followed:</p>\n\n<pre class='inline-example '><code><a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>('Ext.chart.PolarChart', {\n    background: 'white',\n    store: {\n        fields: ['name', 'g1', 'g2', 'g3', 'g4', 'g5'],\n        data: [\n            {\"name\": \"Item-0\", \"g1\": 18.34, \"g2\": 0.04, \"g3\": 22.35, \"g4\": 10.50, \"g5\": 18.42},\n            {\"name\": \"Item-1\", \"g1\": 2.67, \"g2\": 14.87, \"g3\": 0.41, \"g4\": 19.15, \"g5\": 1.64},\n            {\"name\": \"Item-2\", \"g1\": 1.90, \"g2\": 5.72, \"g3\": 14.80, \"g4\": 38.93, \"g5\": 2.77},\n            {\"name\": \"Item-3\", \"g1\": 21.37, \"g2\": 2.13, \"g3\": 12.98, \"g4\": 63.82, \"g5\": 18.85},\n            {\"name\": \"Item-4\", \"g1\": 2.67, \"g2\": 8.53, \"g3\": 4.44, \"g4\": 87.39, \"g5\": 27.23},\n            {\"name\": \"Item-5\", \"g1\": 18.22, \"g2\": 4.62, \"g3\": 8.26, \"g4\": 97.63, \"g5\": 34.37}\n        ]\n    },\n    fullscreen: true,\n\n    innerPadding: 35,\n\n    //bind the chart to a store with the following structure\n    interactions: ['rotate'],\n\n    colors: [\"#115fa6\", \"#94ae0a\", \"#a61120\", \"#ff8809\", \"#ffd13e\", \"#a61187\", \"#24ad9a\", \"#7c7474\", \"#a66111\"],\n\n    //configure the legend.\n    legend: {\n        position: 'right',\n        width: 100\n    },\n\n    //describe the actual pie series.\n    series: [\n        {\n            type: 'pie',\n            xField: 'g1',\n            labelField: 'name',\n            donut: 25,\n            style: {\n                miterLimit: 10,\n                lineCap: 'miter',\n                lineWidth: 2\n            }\n        }\n    ]\n});\n</code></pre>\n\n<h4>Radar</h4>\n\n<p>The Radar series creates a radar chart, a great way to display a comparison of different quantitative values\nfor a constrained number of categories. An example is given as followed:</p>\n\n<pre class='inline-example '><code>// Create a panel to put the chart in.\n<a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>('Ext.chart.PolarChart', {\n    fullscreen: true,\n    innerPadding: 10,\n    store: {\n        fields: ['name', 'g1', 'g2', 'g3', 'g4', 'g5'],\n        data: [\n            {\"name\": \"0\", \"g1\": 18.34, \"g2\": 0.04, \"g3\": 22.35, \"g4\": 10.50, \"g5\": 18.42},\n            {\"name\": \"1\", \"g1\": 2.67, \"g2\": 14.87, \"g3\": 0.41, \"g4\": 19.15, \"g5\": 1.64},\n            {\"name\": \"2\", \"g1\": 1.90, \"g2\": 5.72, \"g3\": 14.80, \"g4\": 38.93, \"g5\": 2.77},\n            {\"name\": \"3\", \"g1\": 21.37, \"g2\": 2.13, \"g3\": 12.98, \"g4\": 63.82, \"g5\": 18.85},\n            {\"name\": \"4\", \"g1\": 2.67, \"g2\": 8.53, \"g3\": 4.44, \"g4\": 87.39, \"g5\": 27.23},\n            {\"name\": \"5\", \"g1\": 18.22, \"g2\": 4.62, \"g3\": 8.26, \"g4\": 97.63, \"g5\": 34.37},\n            {\"name\": \"6\", \"g1\": 28.51, \"g2\": 12.43, \"g3\": 28.67, \"g4\": 108.29, \"g5\": 47.84},\n            {\"name\": \"7\", \"g1\": 34.43, \"g2\": 4.40, \"g3\": 9.89, \"g4\": 127.27, \"g5\": 36.90},\n            {\"name\": \"8\", \"g1\": 21.65, \"g2\": 13.87, \"g3\": 5.44, \"g4\": 112.49, \"g5\": 16.29},\n            {\"name\": \"9\", \"g1\": 12.98, \"g2\": 35.44, \"g3\": 16.37, \"g4\": 135.54, \"g5\": 16.78},\n            {\"name\": \"10\", \"g1\": 22.96, \"g2\": 38.70, \"g3\": 18.15, \"g4\": 114.96, \"g5\": 8.51},\n            {\"name\": \"11\", \"g1\": 0.49, \"g2\": 51.90, \"g3\": 19.98, \"g4\": 95.00, \"g5\": 9.69},\n            {\"name\": \"12\", \"g1\": 20.87, \"g2\": 62.07, \"g3\": 25.96, \"g4\": 87.79, \"g5\": 3.18},\n            {\"name\": \"13\", \"g1\": 25.10, \"g2\": 78.46, \"g3\": 26.04, \"g4\": 91.54, \"g5\": 12.41},\n            {\"name\": \"14\", \"g1\": 16.87, \"g2\": 56.80, \"g3\": 1.39, \"g4\": 71.78, \"g5\": 16.54}\n        ]\n    },\n    background: 'white',\n\n    // Set rotation and double tap reset interactions.\n    interactions: ['rotate'],\n\n    // Define radial and angular axis for the radar chart.\n    axes: [\n        {\n            type: 'numeric',\n            position: 'radial',\n            fields: 'g1',\n            grid: true,\n            style: {\n                estStepSize: 20\n            },\n            label: {\n                fill: 'black',\n                y: -8\n            }\n        },\n        {\n            type: 'category',\n            position: 'angular',\n            fields: 'name',\n            grid: true,\n            style: {\n                estStepSize: 2\n            },\n            label: {\n                fill: 'black'\n            }\n        }\n    ],\n\n    series: [\n        {\n            type: 'radar',\n            xField: 'name',\n            yField: 'g1',\n            style: {\n                fillStyle: 'rgba(0,255,0,0.2)',\n                strokeStyle: 'rgba(0,0,0,0.8)',\n                lineWidth: 1\n            }\n        }\n    ]\n});\n</code></pre>\n\n<p>The following code snippet shows a typical configuration object for the Radar series.</p>\n\n<h4>Scatter</h4>\n\n<p>The scatter series creates a scatter chart, which enables an application to display more than two variables in\nthe same visualization.\nThese variables can be mapped onto x, y coordinates and also to an element's radius/size, color, and so on.</p>\n\n<pre class='inline-example '><code>// Create a panel to put the chart in.\n<a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>('Ext.chart.CartesianChart', {\n    fullscreen: true,\n    innerPadding: 15,\n    store: {\n        fields: ['name', 'g1', 'g2', 'g3', 'g4', 'g5'],\n        data: [\n            {\"name\": \"Item-0\", \"g1\": 18.34, \"g2\": 0.04, \"g3\": 22.35, \"g4\": 10.50, \"g5\": 18.42},\n            {\"name\": \"Item-1\", \"g1\": 2.67, \"g2\": 14.87, \"g3\": 0.41, \"g4\": 19.15, \"g5\": 1.64},\n            {\"name\": \"Item-2\", \"g1\": 1.90, \"g2\": 5.72, \"g3\": 14.80, \"g4\": 38.93, \"g5\": 2.77},\n            {\"name\": \"Item-3\", \"g1\": 21.37, \"g2\": 2.13, \"g3\": 12.98, \"g4\": 63.82, \"g5\": 18.85},\n            {\"name\": \"Item-4\", \"g1\": 2.67, \"g2\": 8.53, \"g3\": 4.44, \"g4\": 87.39, \"g5\": 27.23},\n            {\"name\": \"Item-5\", \"g1\": 18.22, \"g2\": 4.62, \"g3\": 8.26, \"g4\": 97.63, \"g5\": 34.37},\n            {\"name\": \"Item-6\", \"g1\": 28.51, \"g2\": 12.43, \"g3\": 28.67, \"g4\": 108.29, \"g5\": 47.84},\n            {\"name\": \"Item-7\", \"g1\": 34.43, \"g2\": 4.40, \"g3\": 9.89, \"g4\": 127.27, \"g5\": 36.90},\n            {\"name\": \"Item-8\", \"g1\": 21.65, \"g2\": 13.87, \"g3\": 5.44, \"g4\": 112.49, \"g5\": 16.29},\n            {\"name\": \"Item-9\", \"g1\": 12.98, \"g2\": 35.44, \"g3\": 16.37, \"g4\": 135.54, \"g5\": 16.78},\n            {\"name\": \"Item-10\", \"g1\": 22.96, \"g2\": 38.70, \"g3\": 18.15, \"g4\": 114.96, \"g5\": 8.51},\n            {\"name\": \"Item-11\", \"g1\": 0.49, \"g2\": 51.90, \"g3\": 19.98, \"g4\": 95.00, \"g5\": 9.69},\n            {\"name\": \"Item-12\", \"g1\": 20.87, \"g2\": 62.07, \"g3\": 25.96, \"g4\": 87.79, \"g5\": 3.18},\n            {\"name\": \"Item-13\", \"g1\": 25.10, \"g2\": 78.46, \"g3\": 26.04, \"g4\": 91.54, \"g5\": 12.41},\n            {\"name\": \"Item-14\", \"g1\": 16.87, \"g2\": 56.80, \"g3\": 1.39, \"g4\": 71.78, \"g5\": 16.54}\n        ]\n    },\n    background: 'white',\n\n    // Set rotation and double tap reset interactions.\n    interactions: ['rotate'],\n\n    axes: [{\n        type: 'category',\n        position: 'bottom',\n        hidden: true\n    }],\n    series: [\n        {\n            type: 'scatter',\n            xField: 'g1',\n            yField: 'g2',\n            marker: {\n                type: 'circle',\n                radius: 5,\n                fillStyle: 'rgba(0,255,0,0.2)',\n                strokeStyle: 'rgba(0,0,0,0.8)',\n                lineWidth: 1\n            },\n            style: {\n                renderer: function (target, sprite, index, storeItem) {\n                    target.radius = interpolate(storeItem.data.g3, 0, 30, 5, 12);\n                    target.fillOpacity = interpolate(storeItem.data.g3, 0, 30, 1, 0.7);\n                    target.fill = interpolateColor(storeItem.data.g3, 0, 200);\n                }\n            }\n\n        }\n    ]\n});\nfunction interpolate(lambda, minSrc, maxSrc, minDst, maxDst) {\n    return minDst + (maxDst - minDst) * Math.max(0, Math.min(1, (lambda - minSrc) / (maxSrc - minSrc)));\n}\n\nvar fromHSL = Ext.draw.Color.fly('blue').getHSL(),\n    toHSL = Ext.draw.Color.fly('red').getHSL();\nfromHSL[2] = 0.0;\nfromHSL[2] = 0.3;\nfunction interpolateColor(lambda, minSrc, maxSrc) {\n    return Ext.draw.Color.fly(0, 0, 0, 0).setHSL(\n        interpolate(lambda, minSrc, maxSrc, fromHSL[0], toHSL[0]),\n        interpolate(lambda, minSrc, maxSrc, fromHSL[1], toHSL[1]),\n        interpolate(lambda, minSrc, maxSrc, fromHSL[2], toHSL[2])\n    ).toString();\n}\n</code></pre>\n\n<h4>Gauge</h4>\n\n<p>The gauge series creates a gauge chart, typically used to show progress in a certain variable.\nBesides of using stores, you can also simply set a value to the gauge series to show the value.</p>\n\n<p>Gauge series uses space fill chart type.</p>\n\n<p>An example is given as followed:</p>\n\n<pre class='inline-example '><code>var value = 300;\n<a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>(\"<a href=\"#!/api/Ext.Panel\" rel=\"Ext.Panel\" class=\"docClass\">Ext.Panel</a>\", {\n    fullscreen: true,\n    layout: 'fit',\n    items: [\n        {\n            xtype: 'titlebar',\n            docked: 'top',\n            title: 'Gauge Demo',\n            items: [{\n                xtype: 'button',\n                text: 'Smaller',\n                ui: 'back',\n                align: 'left',\n                handler: function () {\n                    if (value &gt; 100) {\n                        value -= 50;\n                        <a href=\"#!/api/Ext.ComponentQuery-method-query\" rel=\"Ext.ComponentQuery-method-query\" class=\"docClass\">Ext.ComponentQuery.query</a>('spacefilling')[0].getSeries()[0].setValue(value);\n                    }\n                }\n            }, {\n                xtype: 'button',\n                text: 'Bigger',\n                ui: 'forward',\n                align: 'right',\n                handler: function () {\n                    if (value &lt; 900) {\n                        value += 50;\n                        <a href=\"#!/api/Ext.ComponentQuery-method-query\" rel=\"Ext.ComponentQuery-method-query\" class=\"docClass\">Ext.ComponentQuery.query</a>('spacefilling')[0].getSeries()[0].setValue(value);\n                    }\n                }\n            }]\n        },\n        {\n            xtype: 'spacefilling',\n            animate: {\n                easing: 'elasticIn',\n                duration: 1000\n            },\n            series: [\n                {\n                    type: 'gauge',\n                    value: value,\n                    minimum: 000,\n                    maximum: 1000,\n                    donut: 30,\n                    style: {\n                        miterLimit: 10,\n                        lineCap: 'miter',\n                        lineWidth: 2\n                    },\n                    subStyle: {\n                        fillStyle: [\"#115fa6\", \"lightgrey\"]\n                    }\n                }\n            ]\n        }\n    ]\n});\n</code></pre>\n\n<h2 id='drawing_and_charting-section-5'>Interactions</h2>\n\n<p>This section introduces the interaction features in Sencha Touch chart package.\nBy taking advantage of these features, you can create highly interactive charts that enables users to visualize\nand navigate complex data sets.</p>\n\n<h3>A Great Mobile Chart User Experience</h3>\n\n<p>Deploying charts on mobile touch devices poses some unique problems over desktop environments:</p>\n\n<ul>\n<li>The small screen size limits the amount and complexity of data that can be displayed at once.</li>\n<li>Touch input makes it difficult for the user to accurately select data points in order to view detailed information.</li>\n<li>Hardware limitations make it hard for mobile devices to redraw chart data.</li>\n</ul>\n\n\n<p>These unique issues make the sort of charts commonly seen on the Web practically unusable on touch devices. In order to deliver a great mobile chart user experience, Touch Charts enables a level of interactivity that is not available with other current charting products. Additionally, Touch Charts interactions provide a high degree of configurability, and they are designed to perform well on mobile hardware.</p>\n\n<p>Let us take a closer look at the interaction types supported by Touch Charts.</p>\n\n<h3>Adding Interactions To Your Chart</h3>\n\n<p>To add interactions to a chart, set the <code>interactions</code> config of the chart to an array of interaction config objects.\nEach object must be an string or contains a <code>type</code> property matching one of the interaction types,\nwhich are described in the subsequent sections. Each object may also contain additional config options that are\nappropriate for a particular interaction.</p>\n\n<p>For example let us consider the following code snippet that creates a Chart and configures interactions on it:</p>\n\n<pre class='inline-example preview'><code><a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>(\"<a href=\"#!/api/Ext.Panel\" rel=\"Ext.Panel\" class=\"docClass\">Ext.Panel</a>\", {\n    fullscreen: true,\n    layout: 'fit',\n    items: [{\n        xtype: 'titlebar',\n        title: 'Try tap hold on bars',\n        docked: \"top\"\n    }, {\n        xtype: 'chart',\n        store: {\n            fields: ['name', 'g1', 'g2', 'g3', 'g4', 'g5'],\n            data: [{\"name\": \"Item-0\", \"g1\": 18.34, \"g2\": 0.04, \"g3\": 22.35, \"g4\": 10.50, \"g5\": 18.42}, {\"name\": \"Item-1\", \"g1\": 2.67, \"g2\": 14.87, \"g3\": 0.41, \"g4\": 19.15, \"g5\": 1.64}, {\"name\": \"Item-2\", \"g1\": 1.90, \"g2\": 5.72, \"g3\": 14.80, \"g4\": 38.93, \"g5\": 2.77}, {\"name\": \"Item-3\", \"g1\": 21.37, \"g2\": 2.13, \"g3\": 12.98, \"g4\": 63.82, \"g5\": 18.85}, {\"name\": \"Item-4\", \"g1\": 2.67, \"g2\": 8.53, \"g3\": 4.44, \"g4\": 87.39, \"g5\": 27.23}, {\"name\": \"Item-5\", \"g1\": 18.22, \"g2\": 4.62, \"g3\": 8.26, \"g4\": 97.63, \"g5\": 34.37}, {\"name\": \"Item-6\", \"g1\": 28.51, \"g2\": 12.43, \"g3\": 28.67, \"g4\": 108.29, \"g5\": 47.84}, {\"name\": \"Item-7\", \"g1\": 34.43, \"g2\": 4.40, \"g3\": 9.89, \"g4\": 127.27, \"g5\": 36.90}, {\"name\": \"Item-8\", \"g1\": 21.65, \"g2\": 13.87, \"g3\": 5.44, \"g4\": 112.49, \"g5\": 16.29}, {\"name\": \"Item-9\", \"g1\": 12.98, \"g2\": 35.44, \"g3\": 16.37, \"g4\": 135.54, \"g5\": 16.78}, {\"name\": \"Item-10\", \"g1\": 22.96, \"g2\": 38.70, \"g3\": 18.15, \"g4\": 114.96, \"g5\": 8.51}, {\"name\": \"Item-11\", \"g1\": 0.49, \"g2\": 51.90, \"g3\": 19.98, \"g4\": 95.00, \"g5\": 9.69}, {\"name\": \"Item-12\", \"g1\": 20.87, \"g2\": 62.07, \"g3\": 25.96, \"g4\": 87.79, \"g5\": 3.18}, {\"name\": \"Item-13\", \"g1\": 25.10, \"g2\": 78.46, \"g3\": 26.04, \"g4\": 91.54, \"g5\": 12.41}, {\"name\": \"Item-14\", \"g1\": 16.87, \"g2\": 56.80, \"g3\": 1.39, \"g4\": 71.78, \"g5\": 16.54}]\n        },\n        axes: [{\n            type: 'numeric',\n            position: 'left',\n            grid: true,\n            maximum: 40\n        }, {\n            type: 'category',\n            position: 'bottom',\n            visibleRange: [0, 0.75]\n        }],\n        series: [{\n            type: 'bar',\n            xField: 'name',\n            yField: 'g1',\n            highlightCfg: {\n                fillStyle: '#f99',\n                strokeStyle: 'black',\n                shadowColor: 'black',\n                shadowBlur: 8,\n                shadowOffsetX: 4,\n                shadowOffsetY: 4,\n            },\n            style: {\n                fillStyle: '#55a',\n                strokeStyle: '#55a'\n            }\n        }],\n        interactions: [\n            // If all you want is to use the default interaction,\n            // simply put its name here.\n            'panzoom',\n            'itemhighlight',\n            {\n                type: 'iteminfo',\n                // For some interactions, you can specify the gesture\n                // to trigger it.\n                gesture: 'itemtaphold',\n                // You can also attach listeners to an interaction.\n                listeners: {\n                    show: function (me, item, panel) {\n                        panel.setHtml(\"Current Item: \" + item.record.data.name);\n                    }\n                }\n            }\n        ]\n    }],\n    listeners: {\n        initialize: function () {\n            // The panzoom interaction provides an toggle button, you can add them anywhere (once).\n            // It will be destroyed when the interaction is destroyed.\n            var button = <a href=\"#!/api/Ext.ComponentQuery-method-query\" rel=\"Ext.ComponentQuery-method-query\" class=\"docClass\">Ext.ComponentQuery.query</a>(\"interaction[type=panzoom]\")[0].getModeToggleButton();\n            <a href=\"#!/api/Ext.ComponentQuery-method-query\" rel=\"Ext.ComponentQuery-method-query\" class=\"docClass\">Ext.ComponentQuery.query</a>(\"titlebar\")[0].add(button);\n        }\n    }\n});\n</code></pre>\n\n<p>This column chart is configured with the following two interactions:</p>\n\n<ul>\n<li><strong><code>panzoom</code></strong> - to allow zooming and panning along the left and bottom axes. You can toggle the mode by click on the\nbutton on the top-left corner.</li>\n<li><strong><code>itemhighlight</code></strong> - to highlight a bar item by tapping on it.</li>\n<li><strong><code>iteminfo</code></strong> - to display detailed information about a series data point in a popup panel on the <code>doubletap</code>\ngesture.</li>\n</ul>\n\n\n<p>You can define you own interaction by implementing Ext.chart.interactions.Abstract class and register the name\nusing an alias with prefix <code>interaction.</code>. For example if you want to create an interaction called <code>remove</code>, create\nan alias of the class named <code>\"interaction.remove\"</code>. Then, you can set the <code>type: 'remove'</code> in the interaction config to\nuse it.</p>\n\n<h3>Gestures</h3>\n\n<p>All of the supported interactions are bound by default to gestures that make sense in most situations,\nhowever you may want to change which gestures trigger which interactions.\nThis is particularly likely when combining interactions whose default gestures collide with one another,\nsuch as the <code>itemhighlight</code> and <code>iteminfo</code> interactions, which are both bound to an <code>tap</code> gesture by default.</p>\n\n<p>To allow for customization of gestures, each interaction exposes one or more <code>gesture</code> config properties.\nFor simple interactions configured with a single gesture use the <code>gesture</code> config, as shown in the following code\nsnippet:</p>\n\n<pre><code>interactions: [{\n    type: 'iteminfo',\n    gesture: 'doubletap' //changed to use doublet instead of the default itemtap gesture\n}]\n</code></pre>\n\n<p>More complex interactions that use more than a single gesture expose multiple <code>fooGesture</code> configs for\ncustomizing each interaction.\nSee the Ext.chart.interactions.Abstract for each interaction class to see which gesture properties it supports.</p>\n\n<h3>Item Highlighting</h3>\n\n<p>The <code>itemhighlight</code> interaction enables you to highlight individual data point items on the chart.\nIt is bound to the <code>tap</code> gesture by default.</p>\n\n<p>The highlight effects can also be customized via the <code>highlightCfg</code> config property on each series.\nThe highlighting effect resulting from the interaction configured in the following code snippet is\nillustrated by the following figure:</p>\n\n<pre><code>interactions: [{\n    type: 'itemhighlight',\n    gesture: 'tap'\n}]\n</code></pre>\n\n<p>This interaction is implemented by the <code>Ext.chart.interactions.ItemHighlight</code> class.\nSee the <a href=\"#!/api/Ext.chart.interactions.ItemHighlight\">class documentation</a> for detailed configuration options.</p>\n\n<h3>Item Info</h3>\n\n<p>The <code>iteminfo</code> interaction enables you to select an individual data point item on the chart and view detailed\ninformation about that item in a popup panel. It is bound to <code>itemtap</code> by default. Although you can use\n<code>gesture</code> config to change that, you still have to bind the interaction on <code>itemXXXX</code> events.</p>\n\n<p>The popup panel that is displayed does not have any default content. Its content is dependent on the particular\ndata model and chart configuration that is being used. You have to implement a handler for the interaction's\n<code>show</code> event to populate the panel. The handler is passed a reference to the interaction instance, the selected item,\nand the panel instance. The effect resulting from the interaction configured in the following code snippet is\nillustrated by the following example:</p>\n\n<pre><code>interactions: [{\n    type: 'iteminfo',\n    gesture: 'doubletap',\n    listeners: {\n        show: function(interaction, item, panel) {\n            panel.setHtml('Stock Price: $' + item.record.get('price'));\n        }\n    }\n}]\n</code></pre>\n\n<p>This interaction is implemented by the <code>Ext.chart.interactions.ItemInfo</code> class.\nSee the <a href=\"#!/api/Ext.chart.interactions.ItemInfo\">class documentation</a> for detailed configuration options.</p>\n\n<h3>Axis Pan/Zoom Navigation</h3>\n\n<p>The <code>panzoom</code> interaction enables users to navigate one or more axes in a Cartesian chart by zooming in/out and panning.\nThis is particularly useful for series with large numbers of data points,\nsince zooming enables users to see details and to interact more easily with individual data points.</p>\n\n<p>You can get a toggle button from the interaction by using <code>getModeToggleButton</code> method and put it any where. It will\nbe destroyed along with the destruction of the interaction.</p>\n\n<p>On devices that support multi-touch events, a two-touch pinch gesture performs a zoom and a single-touch drag performs\na pan. This interaction must be bound to one or more axes. Parameters for the pan/zoom actions can be configured\nindividually for each axis.</p>\n\n<pre><code>interactions: [\n    {\n        type: 'panzoom',\n        axes: {\n            \"left\": {\n                allowPan: false,\n                allowZoom: false\n            },\n            \"bottom\": {\n                allowPan: true,\n                allowZoom: true\n            }\n        }\n    }\n]\n</code></pre>\n\n<p>This interaction is implemented by the <code>Ext.chart.interactions.PanZoom</code> class.\nSee the <a href=\"#!/api/Ext.chart.interactions.PanZoom\">class documentation</a> for detailed configuration options.</p>\n\n<h3>Pie/Radar Rotation</h3>\n\n<p>The <code>rotate</code> interaction enables users to rotate a pie or radar chart.\nBy default users can perform a rotation using a drag gesture.\nThe following code snippet is an example:</p>\n\n<pre><code>interactions: ['rotate']\n</code></pre>\n\n<p>This interaction is implemented by the <code>Ext.chart.interactions.Rotate class</code>.\nSee the <a href=\"#!/api/Ext.chart.interactions.Rotate\">class documentation</a> for detailed configuration options.</p>\n\n<h2 id='drawing_and_charting-section-6'>Legend</h2>\n\n<p>The chart exposes a store to represent legend information\ncollected from series. Technically, you can do anything with this store. Again, this architecture can help you\ndecouple the legend information from the legend component so you can use whatever technology and customization\nto show the legend at whatever place you want to put it.</p>\n\n<p>For you convenience, we also provide a default legend component that already implemented some common and basic\nfunctionality for displaying legend. The Chart configuration object accepts a <code>legend</code> section to enable the\ndefault legend component and insert them in the parent of the chart. The default legend component contains a <code>position</code>\nconfig and it will be docked on that side.</p>\n\n<p>The example below shows how the legend looks when docked on different sides.\nNote that due to the separation between legend information and legend component,\nyou can attached multiple legend to the same chart and they work along with each other magically well.</p>\n\n<pre class='inline-example preview'><code>var cmp = <a href=\"#!/api/Ext-method-create\" rel=\"Ext-method-create\" class=\"docClass\">Ext.create</a>(\"Ext.chart.Chart\", {\n    store: {\n        fields: ['name', 'g1', 'g2', 'g3', 'g4', 'g5'],\n        data: [\n            {\"name\": \"Item-0\", \"g1\": 18.341524994680185, \"g2\": 0.04297258032918805, \"g3\": 22.351114037029276, \"g4\": 10.501821959142115, \"g5\": 18.422488416954124}, {\"name\": \"Item-1\", \"g1\": 2.6795750960073192, \"g2\": 14.875638789052152, \"g3\": 0.41991764062895953, \"g4\": 19.15924362650272, \"g5\": 1.6495555940993327}, {\"name\": \"Item-2\", \"g1\": 1.9082894708999651, \"g2\": 5.729225849931112, \"g3\": 14.809082259901247, \"g4\": 38.935629377514275, \"g5\": 2.7729804343737}, {\"name\": \"Item-3\", \"g1\": 21.372004559042896, \"g2\": 2.131323680889345, \"g3\": 12.98075950737056, \"g4\": 63.8279558143009, \"g5\": 18.852890370148263}, {\"name\": \"Item-4\", \"g1\": 2.678644589238747, \"g2\": 8.533478458163483, \"g3\": 4.442247207672851, \"g4\": 87.39642008886551, \"g5\": 27.236700916073737}, {\"name\": \"Item-5\", \"g1\": 18.22581616728662, \"g2\": 4.6238789653695616, \"g3\": 8.266150112323874, \"g4\": 97.63735394909592, \"g5\": 34.37480220555298}, {\"name\": \"Item-6\", \"g1\": 28.511145638423226, \"g2\": 12.432353979532314, \"g3\": 28.6741228261814, \"g4\": 108.2977419283445, \"g5\": 47.84666069220649}, {\"name\": \"Item-7\", \"g1\": 34.43620878689124, \"g2\": 4.400807521399271, \"g3\": 9.897771308372459, \"g4\": 127.27483400942947, \"g5\": 36.90075111658946}, {\"name\": \"Item-8\", \"g1\": 21.65297419507408, \"g2\": 13.873965184960143, \"g3\": 5.442452028141574, \"g4\": 112.4995128779431, \"g5\": 16.29340203114538}, {\"name\": \"Item-9\", \"g1\": 12.982003004868435, \"g2\": 35.44230021285489, \"g3\": 16.375689050647726, \"g4\": 135.54558258822468, \"g5\": 16.789054656397266}, {\"name\": \"Item-10\", \"g1\": 22.966357646171907, \"g2\": 38.70605529653733, \"g3\": 18.15839081425259, \"g4\": 114.96437921865811, \"g5\": 8.512883775942063}, {\"name\": \"Item-11\", \"g1\": 0.4961773512983534, \"g2\": 51.906332843946664, \"g3\": 19.982581780133525, \"g4\": 95.0096628034602, \"g5\": 9.69666590645371}, {\"name\": \"Item-12\", \"g1\": 20.871287522024215, \"g2\": 62.07049642190715, \"g3\": 25.96145180733678, \"g4\": 87.79060021422934, \"g5\": 3.1888208090676873}, {\"name\": \"Item-13\", \"g1\": 25.10282655149528, \"g2\": 78.46673576692024, \"g3\": 26.04466591703436, \"g4\": 91.54713327066283, \"g5\": 12.412469961213306}, {\"name\": \"Item-14\", \"g1\": 16.879928748894088, \"g2\": 56.800978947642236, \"g3\": 1.3917379459365016, \"g4\": 71.78792090708514, \"g5\": 16.54836327119026}, {\"name\": \"Item-15\", \"g1\": 31.831917729546152, \"g2\": 35.07601255548843, \"g3\": 25.844745424414132, \"g4\": 93.52833383209733, \"g5\": 2.671401561125716}, {\"name\": \"Item-16\", \"g1\": 44.11346876157489, \"g2\": 23.027433139122376, \"g3\": 46.411196237286674, \"g4\": 106.58174110647265, \"g5\": 2.277851404192951}, {\"name\": \"Item-17\", \"g1\": 40.670861391890135, \"g2\": 23.5440618568825, \"g3\": 56.71228987546458, \"g4\": 114.62825504295904, \"g5\": 26.280211845137366}, {\"name\": \"Item-18\", \"g1\": 55.6065040501508, \"g2\": 1.5722659966184906, \"g3\": 77.43817238547803, \"g4\": 130.08908094416222, \"g5\": 12.23868295330551}, {\"name\": \"Item-19\", \"g1\": 46.07941778348976, \"g2\": 10.21326337003686, \"g3\": 60.41723272409542, \"g4\": 125.57289205728488, \"g5\": 3.455769238542464}, {\"name\": \"Item-20\", \"g1\": 61.593189686585355, \"g2\": 3.0287808932196434, \"g3\": 62.962364348922236, \"g4\": 116.50437959216974, \"g5\": 19.021231015303968}, {\"name\": \"Item-21\", \"g1\": 49.131662515684056, \"g2\": 17.359720612610033, \"g3\": 81.85955411171707, \"g4\": 104.35194501037188, \"g5\": 38.019468830156185}, {\"name\": \"Item-22\", \"g1\": 38.505053519952455, \"g2\": 9.397924777062864, \"g3\": 64.1364369949548, \"g4\": 89.23287654726165, \"g5\": 62.22153503719187}, {\"name\": \"Item-23\", \"g1\": 56.45625324619134, \"g2\": 32.961040643270024, \"g3\": 72.43948657468295, \"g4\": 67.10892520115654, \"g5\": 80.64986971100456}, {\"name\": \"Item-24\", \"g1\": 37.22410682076297, \"g2\": 45.05562961930172, \"g3\": 57.567780112761504, \"g4\": 45.04615762614276, \"g5\": 100.00207932829655}, {\"name\": \"Item-25\", \"g1\": 31.942472041872094, \"g2\": 67.8029444580495, \"g3\": 53.55223417785279, \"g4\": 36.91141400902115, \"g5\": 79.66745070976023}, {\"name\": \"Item-26\", \"g1\": 27.389579901973637, \"g2\": 51.55427314558277, \"g3\": 60.697297359605265, \"g4\": 47.301868053483474, \"g5\": 89.06330678114135}, {\"name\": \"Item-27\", \"g1\": 21.76700657982844, \"g2\": 69.1534159811903, \"g3\": 78.94435417727888, \"g4\": 25.332426000355156, \"g5\": 109.82473177890374}, {\"name\": \"Item-28\", \"g1\": 37.76452404604049, \"g2\": 63.21592972099229, \"g3\": 91.7883116482889, \"g4\": 21.77618381260634, \"g5\": 108.62547474389665}, {\"name\": \"Item-29\", \"g1\": 22.15574281743333, \"g2\": 80.02333316902416, \"g3\": 98.08010371357004, \"g4\": 19.28224399835162, \"g5\": 123.46698354865038}\n        ]\n    },\n    animate: false,\n    interactions: ['panzoom'],\n    series: [\n        {\n            type: 'line',\n            xField: 'name',\n            yField: 'g1',\n            title: 'Line1',\n            style: {\n                lineWidth: 2,\n                stroke: 'rgba(0,40,170,0.7)'\n            }\n        },\n        {\n            type: 'line',\n            xField: 'name',\n            yField: 'g2',\n            title: 'Line2',\n            style: {\n                lineWidth: 2,\n                stroke: 'rgba(80,40,170,0.7)'\n            }\n        },\n        {\n            type: 'line',\n            xField: 'name',\n            yField: 'g3',\n            title: 'Line3',\n            style: {\n                lineWidth: 2,\n                stroke: 'rgba(180,40,170,0.7)'\n            }\n        }\n    ],\n    axes: [\n        {\n            type: 'numeric',\n            position: 'left',\n            grid: true\n        },\n        {\n            type: 'category',\n            position: 'bottom',\n            grid: true,\n            visibleRange: [0, 0.5]\n        }\n    ]\n});\n<a href=\"#!/api/Ext.Viewport-method-add\" rel=\"Ext.Viewport-method-add\" class=\"docClass\">Ext.Viewport.add</a>({\n    layout: 'fit',\n    items: [\n        {\n            xtype: 'legend',\n            docked: 'left',\n            width: 90\n        },\n        {\n            xtype: 'legend',\n            docked: 'right',\n            width: 90\n        },\n        {\n            xtype: 'legend',\n            docked: 'top'\n        },\n        {\n            xtype: 'legend',\n            docked: 'bottom'\n        },\n        cmp\n    ]\n});\nvar legends = <a href=\"#!/api/Ext.ComponentQuery-method-query\" rel=\"Ext.ComponentQuery-method-query\" class=\"docClass\">Ext.ComponentQuery.query</a>('legend');\nlegends[0].setStore(cmp.getLegendStore());\nlegends[1].setStore(cmp.getLegendStore());\nlegends[2].setStore(cmp.getLegendStore());\nlegends[3].setStore(cmp.getLegendStore());\n</code></pre>\n"});